@@ -1,7 +1,10 @@
-from sklearn.model_selection import KFold, StratifiedKFold
+import pandas as pd
+from sklearn.model_selection import KFold
 
 from evalml.objectives import get_objective
 from evalml.preprocessing.data_splitters import (
+    BalancedClassificationDataCVSplit,
+    BalancedClassificationDataTVSplit,
     TimeSeriesSplit,
     TrainingValidationSplit
 )
@@ -57,18 +60,20 @@ def make_data_splitter(X, y, problem_type, problem_configuration=None, n_splits=
     """
     random_seed = deprecate_arg("random_state", "random_seed", random_state, random_seed)
     problem_type = handle_problem_types(problem_type)
-    if X.shape[0] > _LARGE_DATA_ROW_THRESHOLD:
-        return TrainingValidationSplit(test_size=_LARGE_DATA_PERCENT_VALIDATION, shuffle=True)
-
-    if problem_type == ProblemTypes.REGRESSION:
-        return KFold(n_splits=n_splits, random_state=random_seed, shuffle=shuffle)
-    elif problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
-        return StratifiedKFold(n_splits=n_splits, random_state=random_seed, shuffle=shuffle)
-    elif is_time_series(problem_type):
+    if is_time_series(problem_type):
         if not problem_configuration:
             raise ValueError("problem_configuration is required for time series problem types")
         return TimeSeriesSplit(n_splits=n_splits, gap=problem_configuration.get('gap'),
                                max_delay=problem_configuration.get('max_delay'))
+    if X.shape[0] > _LARGE_DATA_ROW_THRESHOLD:
+        if problem_type == ProblemTypes.REGRESSION:
+            return TrainingValidationSplit(test_size=_LARGE_DATA_PERCENT_VALIDATION, shuffle=shuffle)
+        elif problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
+            return BalancedClassificationDataTVSplit(test_size=_LARGE_DATA_PERCENT_VALIDATION, shuffle=shuffle, random_seed=random_seed)
+    if problem_type == ProblemTypes.REGRESSION:
+        return KFold(n_splits=n_splits, random_state=random_seed, shuffle=shuffle)
+    elif problem_type in [ProblemTypes.BINARY, ProblemTypes.MULTICLASS]:
+        return BalancedClassificationDataCVSplit(n_splits=n_splits, random_seed=random_seed, shuffle=shuffle)
 
 
 def tune_binary_threshold(pipeline, objective, problem_type, X_threshold_tuning, y_threshold_tuning):
@@ -85,3 +90,24 @@ def tune_binary_threshold(pipeline, objective, problem_type, X_threshold_tuning,
             y_predict_proba = pipeline.predict_proba(X_threshold_tuning)
             y_predict_proba = y_predict_proba.iloc[:, 1]
             pipeline.threshold = objective.optimize_threshold(y_predict_proba, y_threshold_tuning, X=X_threshold_tuning)
+
+
+def check_all_pipeline_names_unique(pipelines):
+    """Checks whether all the pipeline names are unique.
+
+    Arguments:
+        pipelines (list(PipelineBase)): List of pipelines to check if all names are unique.
+
+    Returns:
+          None
+
+    Raises:
+        ValueError: if any pipeline names are duplicated.
+    """
+    name_count = pd.Series([p.name for p in pipelines]).value_counts()
+    duplicate_names = name_count[name_count > 1].index.tolist()
+
+    if duplicate_names:
+        plural, tense = ("s", "were") if len(duplicate_names) > 1 else ("", "was")
+        duplicates = ", ".join([f"'{name}'" for name in sorted(duplicate_names)])
+        raise ValueError(f"All pipeline names must be unique. The name{plural} {duplicates} {tense} repeated.")
