@@ -1,6 +1,7 @@
 from .data_check import DataCheck
 from .data_check_message_code import DataCheckMessageCode
-
+from .data_check_action import DataCheckAction
+from .data_check_action_code import DataCheckActionCode
 from .data_checks import AutoMLDataChecks, DataChecks
 from .data_check_message import DataCheckMessage, DataCheckWarning, DataCheckError
 from .data_check_message_type import DataCheckMessageType
@@ -13,7 +14,6 @@ from .target_leakage_data_check import TargetLeakageDataCheck
 from .outliers_data_check import OutliersDataCheck
 from .no_variance_data_check import NoVarianceDataCheck
 from .class_imbalance_data_check import ClassImbalanceDataCheck
-from .high_variance_cv_data_check import HighVarianceCVDataCheck
 from .multicollinearity_data_check import MulticollinearityDataCheck
 from .sparsity_data_check import SparsityDataCheck
 from .uniqueness_data_check import UniquenessDataCheck
