@@ -69,23 +69,26 @@ class TargetLeakageDataCheck(DataCheck):
         Example:
             >>> import pandas as pd
             >>> X = pd.DataFrame({
-            ...    'leak': [10, 42, 31, 51, 61],
+            ...    'leak': [10, 44, 31, 51, 44],
             ...    'x': [42, 54, 12, 64, 12],
             ...    'y': [13, 5, 13, 74, 24],
             ... })
-            >>> y = pd.Series([10, 42, 31, 51, 40])
+            >>> y = pd.Series([10, 42, 31, 51, 42])
             >>> target_leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.95)
             >>> assert target_leakage_check.validate(X, y) == {"warnings": [{"message": "Column 'leak' is 95.0% or more correlated with the target",\
                                                                              "data_check_name": "TargetLeakageDataCheck",\
                                                                              "level": "warning",\
                                                                              "code": "TARGET_LEAKAGE",\
                                                                              "details": {"column": "leak"}}],\
-                                                               "errors": []}
+                                                               "errors": [],\
+                                                               "actions": []}
         """
-        messages = {
+        results = {
             "warnings": [],
-            "errors": []
+            "errors": [],
+            "actions": []
         }
+
         X = infer_feature_types(X)
         y = infer_feature_types(y)
 
@@ -97,9 +100,9 @@ class TargetLeakageDataCheck(DataCheck):
             highly_corr_cols = self._calculate_mutual_information(X, y)
 
         warning_msg = "Column '{}' is {}% or more correlated with the target"
-        messages["warnings"].extend([DataCheckWarning(message=warning_msg.format(col_name, self.pct_corr_threshold * 100),
-                                                      data_check_name=self.name,
-                                                      message_code=DataCheckMessageCode.TARGET_LEAKAGE,
-                                                      details={"column": col_name}).to_dict()
-                                     for col_name in highly_corr_cols])
-        return messages
+        results["warnings"].extend([DataCheckWarning(message=warning_msg.format(col_name, self.pct_corr_threshold * 100),
+                                                     data_check_name=self.name,
+                                                     message_code=DataCheckMessageCode.TARGET_LEAKAGE,
+                                                     details={"column": col_name}).to_dict()
+                                    for col_name in highly_corr_cols])
+        return results
