@@ -4,13 +4,14 @@ import pandas as pd
 from texttable import Texttable
 
 from evalml.model_understanding.prediction_explanations._algorithms import (
+    _aggregate_shap_values,
     _compute_shap_values,
     _normalize_shap_values
 )
 from evalml.problem_types import ProblemTypes
 
 
-def _make_rows(shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False,
+def _make_rows(shap_values, normalized_values, pipeline_features, original_features, top_k, include_shap_values=False,
                convert_numeric_to_string=True):
     """Makes the rows (one row for each feature) for the SHAP table.
 
@@ -18,6 +19,9 @@ def _make_rows(shap_values, normalized_values, pipeline_features, top_k, include
         shap_values (dict): Dictionary mapping the feature names to their SHAP values. In a multiclass setting,
             this dictionary for correspond to the SHAP values for a single class.
         normalized_values (dict): Normalized SHAP values. Same structure as shap_values parameter.
+        pipeline_features (pd.Series): The features created by the pipeline.
+        original_features (pd.Series): The features passed to the pipeline by the user. If possible,
+            will display the original feature value.
         top_k (int): How many of the highest/lowest features to include in the table.
         include_shap_values (bool): Whether to include the SHAP values in their own column.
         convert_numeric_to_string (bool): Whether numeric values should be converted to strings from numeric
@@ -38,7 +42,15 @@ def _make_rows(shap_values, normalized_values, pipeline_features, top_k, include
     for value, feature_name in features_to_display:
         symbol = "+" if value >= 0 else "-"
         display_text = symbol * min(int(abs(value) // 0.2) + 1, 5)
-        feature_value = pipeline_features[feature_name].iloc[0]
+
+        # At this point, the feature is either in the original data or the data
+        # the final estimator sees. So if it is not a pipeline feature, it is
+        # an original feature
+        if feature_name in pipeline_features.columns:
+            feature_value = pipeline_features[feature_name].iloc[0]
+        else:
+            feature_value = original_features[feature_name].iloc[0]
+
         if convert_numeric_to_string:
             if pd.api.types.is_number(feature_value) and not pd.api.types.is_bool(feature_value):
                 feature_value = "{:.2f}".format(feature_value)
@@ -92,7 +104,8 @@ def _make_json_serializable(value):
     return value
 
 
-def _make_text_table(shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
+def _make_text_table(shap_values, normalized_values, pipeline_features, original_features,
+                     top_k, include_shap_values=False):
     """Make a table displaying the SHAP values for a prediction.
 
     Arguments:
@@ -119,7 +132,7 @@ def _make_text_table(shap_values, normalized_values, pipeline_features, top_k, i
         header.append("SHAP Value")
 
     rows = [header]
-    rows += _make_rows(shap_values, normalized_values, pipeline_features, top_k, include_shap_values)
+    rows += _make_rows(shap_values, normalized_values, pipeline_features, original_features, top_k, include_shap_values)
     table.add_rows(rows)
     return table.draw()
 
@@ -127,16 +140,51 @@ def _make_text_table(shap_values, normalized_values, pipeline_features, top_k, i
 class _TableMaker(abc.ABC):
     """Makes a SHAP table for a regression, binary, or multiclass classification problem."""
 
+    def __init__(self, top_k, include_shap_values, provenance):
+        self.top_k = top_k
+        self.include_shap_values = include_shap_values
+        self.provenance = provenance
+
+    @staticmethod
+    def make_drill_down_dict(provenance, shap_values, normalized_values, pipeline_features,
+                             original_features, include_shap_values):
+        """Format the 'drill_down' section of the explanation report when output_format="dict"
+
+        This section will include the feature values, feature names, qualitative explanation
+        and shap values (if include_shap_values=True) for the features created from one of the
+        original features in the data.
+        """
+        drill_down = {}
+        for parent_feature, children_features in provenance.items():
+            shap_for_children = {k: v for k, v in shap_values.items() if k in children_features}
+            agg_for_children = {k: v for k, v in normalized_values.items() if k in children_features}
+            top_k = len(agg_for_children)
+            rows = _make_rows(shap_for_children, agg_for_children, pipeline_features, original_features,
+                              top_k=top_k, include_shap_values=include_shap_values, convert_numeric_to_string=False)
+            drill_down[parent_feature] = _rows_to_dict(rows)
+        return drill_down
+
     @abc.abstractmethod
-    def make_text(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
+    def make_text(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
         """Creates a table given shap values and formats it as text."""
 
     @abc.abstractmethod
-    def make_dict(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
+    def make_dict(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
         """Creates a table given shap values and formats it as dictionary."""
 
-    def make_dataframe(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
-        data = self.make_dict(shap_values, normalized_values, pipeline_features, top_k, include_shap_values)['explanations']
+    def make_dataframe(self, aggregated_shap_values, aggregated_normalized_values,
+                       shap_values, normalized_values, pipeline_features, original_features):
+        data = self.make_dict(aggregated_shap_values, aggregated_normalized_values,
+                              shap_values=shap_values, normalized_values=normalized_values,
+                              pipeline_features=pipeline_features, original_features=original_features)['explanations']
+
+        # Not including the drill down dict for dataframes
+        # 'drill_down' is always included in the dict output so we can delete it
+        for d in data:
+            del d['drill_down']
+
         df = pd.concat(map(pd.DataFrame, data)).reset_index(drop=True)
         if "class_name" in df.columns and df['class_name'].isna().all():
             df = df.drop(columns=['class_name'])
@@ -146,69 +194,95 @@ class _TableMaker(abc.ABC):
 class _RegressionSHAPTable(_TableMaker):
     """Makes a SHAP table explaining a prediction for a regression problems."""
 
-    def make_text(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
-        return _make_text_table(shap_values, normalized_values, pipeline_features, top_k, include_shap_values)
+    def make_text(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
+        return _make_text_table(aggregated_shap_values, aggregated_normalized_values, pipeline_features, original_features,
+                                self.top_k, self.include_shap_values)
 
-    def make_dict(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
-        rows = _make_rows(shap_values, normalized_values, pipeline_features, top_k, include_shap_values,
-                          convert_numeric_to_string=False)
+    def make_dict(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
+        rows = _make_rows(aggregated_shap_values, aggregated_normalized_values, pipeline_features, original_features,
+                          self.top_k, self.include_shap_values, convert_numeric_to_string=False)
         json_rows = _rows_to_dict(rows)
+        drill_down = self.make_drill_down_dict(self.provenance, shap_values, normalized_values,
+                                               pipeline_features, original_features, self.include_shap_values)
         json_rows["class_name"] = None
+        json_rows["drill_down"] = drill_down
         return {"explanations": [json_rows]}
 
 
 class _BinarySHAPTable(_TableMaker):
     """Makes a SHAP table explaining a prediction for a binary classification problem."""
 
-    def __init__(self, class_names):
+    def __init__(self, top_k, include_shap_values, class_names, provenance):
+        super().__init__(top_k, include_shap_values, provenance)
         self.class_names = class_names
 
-    def make_text(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
+    def make_text(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
         # The SHAP algorithm will return a two-element list for binary problems.
         # By convention, we display the explanation for the dominant class.
-        return _make_text_table(shap_values[1], normalized_values[1], pipeline_features, top_k, include_shap_values)
+        return _make_text_table(aggregated_shap_values[1], aggregated_normalized_values[1],
+                                pipeline_features, original_features, self.top_k, self.include_shap_values)
 
-    def make_dict(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
-        rows = _make_rows(shap_values[1], normalized_values[1], pipeline_features, top_k, include_shap_values,
-                          convert_numeric_to_string=False)
-        json_rows = _rows_to_dict(rows)
-        json_rows["class_name"] = _make_json_serializable(self.class_names[1])
-        return {"explanations": [json_rows]}
+    def make_dict(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
+        rows = _make_rows(aggregated_shap_values[1], aggregated_normalized_values[1], pipeline_features, original_features,
+                          self.top_k, self.include_shap_values, convert_numeric_to_string=False)
+        dict_rows = _rows_to_dict(rows)
+        drill_down = self.make_drill_down_dict(self.provenance, shap_values[1], normalized_values[1],
+                                               pipeline_features, original_features, self.include_shap_values)
+        dict_rows["drill_down"] = drill_down
+        dict_rows["class_name"] = _make_json_serializable(self.class_names[1])
+        return {"explanations": [dict_rows]}
 
 
 class _MultiClassSHAPTable(_TableMaker):
     """Makes a SHAP table explaining a prediction for a multiclass classification problem."""
 
-    def __init__(self, class_names):
+    def __init__(self, top_k, include_shap_values, class_names, provenance):
+        super().__init__(top_k, include_shap_values, provenance)
         self.class_names = class_names
 
-    def make_text(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
+    def make_text(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
         strings = []
-        for class_name, class_values, normalized_class_values in zip(self.class_names, shap_values, normalized_values):
+        for class_name, class_values, normalized_class_values in zip(self.class_names, aggregated_shap_values,
+                                                                     aggregated_normalized_values):
             strings.append(f"Class: {class_name}\n")
-            table = _make_text_table(class_values, normalized_class_values, pipeline_features, top_k, include_shap_values)
+            table = _make_text_table(class_values, normalized_class_values, pipeline_features, original_features,
+                                     self.top_k, self.include_shap_values)
             strings += table.splitlines()
             strings.append("\n")
         return "\n".join(strings)
 
-    def make_dict(self, shap_values, normalized_values, pipeline_features, top_k, include_shap_values=False):
+    def make_dict(self, aggregated_shap_values, aggregated_normalized_values,
+                  shap_values, normalized_values, pipeline_features, original_features):
         json_output = []
-        for class_name, class_values, normalized_class_values in zip(self.class_names, shap_values, normalized_values):
-            rows = _make_rows(class_values, normalized_class_values, pipeline_features, top_k, include_shap_values,
-                              convert_numeric_to_string=False)
+        for class_index, class_name in enumerate(self.class_names):
+            rows = _make_rows(aggregated_shap_values[class_index], aggregated_normalized_values[class_index],
+                              pipeline_features, original_features, self.top_k,
+                              self.include_shap_values, convert_numeric_to_string=False)
             json_output_for_class = _rows_to_dict(rows)
+            drill_down = self.make_drill_down_dict(self.provenance, shap_values[class_index],
+                                                   normalized_values[class_index], pipeline_features, original_features,
+                                                   self.include_shap_values)
+            json_output_for_class["drill_down"] = drill_down
             json_output_for_class["class_name"] = _make_json_serializable(class_name)
             json_output.append(json_output_for_class)
         return {"explanations": json_output}
 
 
-def _make_single_prediction_shap_table(pipeline, pipeline_features, index_to_explain, top_k=3,
+def _make_single_prediction_shap_table(pipeline, pipeline_features, input_features, index_to_explain, top_k=3,
                                        include_shap_values=False, output_format="text"):
     """Creates table summarizing the top_k_features positive and top_k_features negative contributing features to the prediction of a single datapoint.
 
     Arguments:
         pipeline (PipelineBase): Fitted pipeline whose predictions we want to explain with SHAP.
         pipeline_features (pd.DataFrame): Dataframe of features computed by the pipeline.
+        input_features (pd.DataFrame): Dataframe of features passed to the pipeline. This is where the pipeline_features
+            come from.
+        index_to_explain (int): Index in the pipeline_features/input_features to explain.
         top_k (int): How many of the highest/lowest features to include in the table.
         training_data (pd.DataFrame): Training data the pipeline was fit on.
             This is required for non-tree estimators because we need a sample of training data for the KernelSHAP algorithm.
@@ -223,27 +297,34 @@ def _make_single_prediction_shap_table(pipeline, pipeline_features, index_to_exp
         ValueError: if requested index results in a NaN in the computed features.
     """
     pipeline_features_row = pipeline_features.iloc[[index_to_explain]]
+    input_features_row = input_features.iloc[[index_to_explain]]
     if pipeline_features_row.isna().any(axis=None):
         raise ValueError(f"Requested index ({index_to_explain}) produces NaN in features.")
+
     shap_values = _compute_shap_values(pipeline, pipeline_features_row, training_data=pipeline_features.dropna(axis=0))
-    normalized_shap_values = _normalize_shap_values(shap_values)
+    normalized_values = _normalize_shap_values(shap_values)
+
+    provenance = pipeline._get_feature_provenance()
+    aggregated_shap_values = _aggregate_shap_values(shap_values, provenance)
+    aggregated_normalized_shap_values = _normalize_shap_values(aggregated_shap_values)
 
     class_names = None
     if hasattr(pipeline, "classes_"):
         class_names = pipeline.classes_
 
-    table_makers = {ProblemTypes.REGRESSION: _RegressionSHAPTable(),
-                    ProblemTypes.BINARY: _BinarySHAPTable(class_names),
-                    ProblemTypes.MULTICLASS: _MultiClassSHAPTable(class_names),
-                    ProblemTypes.TIME_SERIES_REGRESSION: _RegressionSHAPTable(),
-                    ProblemTypes.TIME_SERIES_BINARY: _BinarySHAPTable(class_names),
-                    ProblemTypes.TIME_SERIES_MULTICLASS: _MultiClassSHAPTable(class_names)}
+    table_makers = {ProblemTypes.REGRESSION: _RegressionSHAPTable(top_k, include_shap_values, provenance),
+                    ProblemTypes.BINARY: _BinarySHAPTable(top_k, include_shap_values, class_names, provenance),
+                    ProblemTypes.MULTICLASS: _MultiClassSHAPTable(top_k, include_shap_values, class_names, provenance),
+                    ProblemTypes.TIME_SERIES_REGRESSION: _RegressionSHAPTable(top_k, include_shap_values, provenance),
+                    ProblemTypes.TIME_SERIES_BINARY: _BinarySHAPTable(top_k, include_shap_values, class_names, provenance),
+                    ProblemTypes.TIME_SERIES_MULTICLASS: _MultiClassSHAPTable(top_k, include_shap_values, class_names, provenance)}
 
     table_maker_class = table_makers[pipeline.problem_type]
     table_maker = {"text": table_maker_class.make_text, "dict": table_maker_class.make_dict,
                    "dataframe": table_maker_class.make_dataframe}[output_format]
 
-    return table_maker(shap_values, normalized_shap_values, pipeline_features_row, top_k, include_shap_values)
+    return table_maker(aggregated_shap_values, aggregated_normalized_shap_values,
+                       shap_values, normalized_values, pipeline_features_row, input_features_row)
 
 
 class _SectionMaker(abc.ABC):
@@ -395,7 +476,7 @@ class _SHAPTable(_SectionMaker):
         self.top_k_features = top_k_features
         self.include_shap_values = include_shap_values
 
-    def make_text(self, index, pipeline, pipeline_features):
+    def make_text(self, index, pipeline, pipeline_features, input_features):
         """Makes the SHAP table section for reports formatted as text.
 
         The table is the same whether the user requests a best/worst report or they manually specified the
@@ -408,9 +489,10 @@ class _SHAPTable(_SectionMaker):
             index (int): The index of the prediction in the dataset.
             pipeline (PipelineBase): The pipeline to explain.
             pipeline_features (pd.DataFrame): The dataframe of features created by the pipeline.
-            y (pd.Series):
+            input_features (pd.Dataframe): The dataframe of features passed to the pipeline.
         """
         table = _make_single_prediction_shap_table(pipeline, pipeline_features,
+                                                   input_features,
                                                    index_to_explain=index,
                                                    top_k=self.top_k_features,
                                                    include_shap_values=self.include_shap_values, output_format="text")
@@ -418,18 +500,19 @@ class _SHAPTable(_SectionMaker):
         # Indent the rows of the table to match the indentation of the entire report.
         return ["\t\t" + line + "\n" for line in table] + ["\n\n"]
 
-    def make_dict(self, index, pipeline, pipeline_features):
+    def make_dict(self, index, pipeline, pipeline_features, input_features):
         """Makes the SHAP table section formatted as a dictionary."""
-        json_output = _make_single_prediction_shap_table(pipeline, pipeline_features,
+        json_output = _make_single_prediction_shap_table(pipeline, pipeline_features, input_features,
                                                          index_to_explain=index,
                                                          top_k=self.top_k_features,
                                                          include_shap_values=self.include_shap_values,
                                                          output_format="dict")
         return json_output
 
-    def make_dataframe(self, index, pipeline, pipeline_features):
+    def make_dataframe(self, index, pipeline, pipeline_features, input_features):
         """Makes the SHAP table section formatted as a dataframe."""
         return _make_single_prediction_shap_table(pipeline, pipeline_features,
+                                                  input_features,
                                                   index_to_explain=index,
                                                   top_k=self.top_k_features,
                                                   include_shap_values=self.include_shap_values,
@@ -475,7 +558,8 @@ class _ReportMaker:
                                                                          pd.Series(data.pipeline_features.index)))
             else:
                 report.extend([""])
-            report.extend(self.table_maker.make_text(index, data.pipeline, data.pipeline_features))
+            report.extend(self.table_maker.make_text(index, data.pipeline, data.pipeline_features,
+                                                     data.input_features))
         return "".join(report)
 
     def make_dict(self, data):
@@ -498,14 +582,16 @@ class _ReportMaker:
                                                                                          data.y_true, data.errors,
                                                                                          pd.Series(data.pipeline_features.index))
             section["explanations"] = self.table_maker.make_dict(index, data.pipeline,
-                                                                 data.pipeline_features)["explanations"]
+                                                                 data.pipeline_features,
+                                                                 data.input_features)["explanations"]
             report.append(section)
         return {"explanations": report}
 
     def make_dataframe(self, data):
         report = []
         for rank, index in enumerate(data.index_list):
-            shap_table = self.table_maker.make_dataframe(index, data.pipeline, data.pipeline_features)
+            shap_table = self.table_maker.make_dataframe(index, data.pipeline, data.pipeline_features,
+                                                         data.input_features)
             if self.make_predicted_values_maker:
                 heading = self.make_predicted_values_maker.make_dataframe(index, data.y_pred, data.y_true, data.errors,
                                                                           pd.Series(data.pipeline_features.index))
