@@ -57,11 +57,3 @@ from .regression import (
     MeanBaselineRegressionPipeline,
 )
 from .time_series_baselines import TimeSeriesBaselineRegressionPipeline, TimeSeriesBaselineBinaryPipeline, TimeSeriesBaselineMulticlassPipeline
-from .generated_pipelines import (
-    GeneratedPipelineBinary,
-    GeneratedPipelineMulticlass,
-    GeneratedPipelineRegression,
-    GeneratedPipelineTimeSeriesBinary,
-    GeneratedPipelineTimeSeriesMulticlass,
-    GeneratedPipelineTimeSeriesRegression
-)
