@@ -2,7 +2,6 @@
 import pandas as pd
 from sklearn.preprocessing import LabelEncoder
 
-from evalml.objectives import get_objective
 from evalml.pipelines import PipelineBase
 from evalml.utils import _convert_woodwork_types_wrapper, infer_feature_types
 
@@ -88,7 +87,7 @@ class ClassificationPipeline(PipelineBase):
         Returns:
             ww.DataColumn: Estimated labels
         """
-        predictions = self._predict(X, objective).to_series()
+        predictions = self._predict(X, objective=objective).to_series()
         predictions = pd.Series(self._decode_targets(predictions), name=self.input_target_name)
         return infer_feature_types(predictions)
 
@@ -119,7 +118,7 @@ class ClassificationPipeline(PipelineBase):
         """
         y = infer_feature_types(y)
         y = _convert_woodwork_types_wrapper(y.to_series())
-        objectives = [get_objective(o, return_instance=True) for o in objectives]
+        objectives = self.create_objectives(objectives)
         y = self._encode_targets(y)
         y_predicted, y_predicted_proba = self._compute_predictions(X, y, objectives)
         if y_predicted is not None:
