@@ -146,6 +146,8 @@ class ComponentGraph:
                 parent_output = infer_feature_types(parent_output)
             final_component_inputs.append(parent_output)
         concatted = pd.concat([component_input.to_dataframe() for component_input in final_component_inputs], axis=1)
+        if needs_fitting:
+            self.input_feature_names.update({self.compute_order[-1]: list(concatted.columns)})
         return infer_feature_types(concatted)
 
     def predict(self, X):
