@@ -3,8 +3,11 @@ from skopt.space import Integer, Real
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
-from evalml.utils import get_random_seed, import_or_raise
-from evalml.utils.gen_utils import _rename_column_names_to_numeric
+from evalml.utils.gen_utils import (
+    _rename_column_names_to_numeric,
+    deprecate_arg,
+    import_or_raise
+)
 
 
 class XGBoostClassifier(Estimator):
@@ -25,8 +28,9 @@ class XGBoostClassifier(Estimator):
     SEED_MIN = -2**31
     SEED_MAX = 2**31 - 1
 
-    def __init__(self, eta=0.1, max_depth=6, min_child_weight=1, n_estimators=100, random_state=0, **kwargs):
-        random_seed = get_random_seed(random_state, self.SEED_MIN, self.SEED_MAX)
+    def __init__(self, eta=0.1, max_depth=6, min_child_weight=1, n_estimators=100, random_state=None,
+                 random_seed=0, **kwargs):
+        random_seed = deprecate_arg("random_state", "random_seed", random_state, random_seed)
         parameters = {"eta": eta,
                       "max_depth": max_depth,
                       "min_child_weight": min_child_weight,
@@ -34,23 +38,26 @@ class XGBoostClassifier(Estimator):
         parameters.update(kwargs)
         xgb_error_msg = "XGBoost is not installed. Please install using `pip install xgboost.`"
         xgb = import_or_raise("xgboost", error_msg=xgb_error_msg)
-        xgb_classifier = xgb.XGBClassifier(**parameters,
-                                           random_state=random_seed)
+        xgb_classifier = xgb.XGBClassifier(random_state=random_seed,
+                                           **parameters)
 
         super().__init__(parameters=parameters,
                          component_obj=xgb_classifier,
-                         random_state=random_state)
+                         random_seed=random_seed)
 
     def fit(self, X, y=None):
-        X = _rename_column_names_to_numeric(X)
-        return super().fit(X, y)
+        X, y = super()._manage_woodwork(X, y)
+        self.input_feature_names = list(X.columns)
+        X = _rename_column_names_to_numeric(X, flatten_tuples=False)
+        self._component_obj.fit(X, y)
+        return self
 
     def predict(self, X):
-        X = _rename_column_names_to_numeric(X)
+        X = _rename_column_names_to_numeric(X, flatten_tuples=False)
         return super().predict(X)
 
     def predict_proba(self, X):
-        X = _rename_column_names_to_numeric(X)
+        X = _rename_column_names_to_numeric(X, flatten_tuples=False)
         return super().predict_proba(X)
 
     @property
