@@ -3,6 +3,7 @@ from sklearn.linear_model import LinearRegression as SKLinearRegression
 from evalml.model_family import ModelFamily
 from evalml.pipelines.components.estimators import Estimator
 from evalml.problem_types import ProblemTypes
+from evalml.utils import deprecate_arg
 
 
 class LinearRegressor(Estimator):
@@ -15,7 +16,7 @@ class LinearRegressor(Estimator):
     model_family = ModelFamily.LINEAR_MODEL
     supported_problem_types = [ProblemTypes.REGRESSION, ProblemTypes.TIME_SERIES_REGRESSION]
 
-    def __init__(self, fit_intercept=True, normalize=False, n_jobs=-1, random_state=0, **kwargs):
+    def __init__(self, fit_intercept=True, normalize=False, n_jobs=-1, random_state=None, random_seed=0, **kwargs):
         parameters = {
             'fit_intercept': fit_intercept,
             'normalize': normalize,
@@ -23,9 +24,10 @@ class LinearRegressor(Estimator):
         }
         parameters.update(kwargs)
         linear_regressor = SKLinearRegression(**parameters)
+        random_seed = deprecate_arg("random_state", "random_seed", random_state, random_seed)
         super().__init__(parameters=parameters,
                          component_obj=linear_regressor,
-                         random_state=random_state)
+                         random_seed=random_seed)
 
     @property
     def feature_importance(self):
