@@ -1,11 +1,17 @@
 import pandas as pd
+from woodwork.logical_types import Categorical
 
 from ..transformer import Transformer
 
 from evalml.pipelines.components.transformers.encoders.onehot_encoder import (
     OneHotEncoderMeta
 )
-from evalml.utils import import_or_raise
+from evalml.utils import (
+    _convert_woodwork_types_wrapper,
+    _retain_custom_types_and_initalize_woodwork,
+    import_or_raise,
+    infer_feature_types
+)
 
 
 class TargetEncoder(Transformer, metaclass=OneHotEncoderMeta):
@@ -18,7 +24,8 @@ class TargetEncoder(Transformer, metaclass=OneHotEncoderMeta):
                  smoothing=1.0,
                  handle_unknown='value',
                  handle_missing='value',
-                 random_state=0,
+                 random_state=None,
+                 random_seed=0,
                  **kwargs):
         """Initializes a transformer that encodes categorical features into target encodings.
 
@@ -49,15 +56,22 @@ class TargetEncoder(Transformer, metaclass=OneHotEncoderMeta):
         category_encode = import_or_raise('category_encoders', error_msg='category_encoders not installed. Please install using `pip install category_encoders`')
         super().__init__(parameters=parameters,
                          component_obj=category_encode.target_encoder.TargetEncoder(**parameters),
-                         random_state=random_state)
+                         random_state=random_state,
+                         random_seed=random_seed)
 
     def fit(self, X, y):
-        if isinstance(X, pd.DataFrame):
-            X.reset_index(drop=True, inplace=True)
-        if isinstance(y, pd.Series):
-            y.reset_index(drop=True, inplace=True)
         return super().fit(X, y)
 
+    def transform(self, X, y=None):
+        X_ww = infer_feature_types(X)
+        X = _convert_woodwork_types_wrapper(X_ww.to_dataframe())
+        if y is not None:
+            y = infer_feature_types(y)
+            y = _convert_woodwork_types_wrapper(y.to_series())
+        X_t = self._component_obj.transform(X, y)
+        X_t_df = pd.DataFrame(X_t, columns=X.columns, index=X.index)
+        return _retain_custom_types_and_initalize_woodwork(X_ww, X_t_df, ltypes_to_ignore=[Categorical])
+
     def fit_transform(self, X, y):
         return self.fit(X, y).transform(X, y)
 
@@ -68,3 +82,6 @@ class TargetEncoder(Transformer, metaclass=OneHotEncoderMeta):
             np.array: The feature names after encoding
         """
         return self._component_obj.get_feature_names()
+
+    def _get_feature_provenance(self):
+        return {col: col for col in self.get_feature_names()}
