@@ -5,6 +5,8 @@ from skopt.space import Real
 
 from .feature_selector import FeatureSelector
 
+from evalml.utils import deprecate_arg
+
 
 class RFRegressorSelectFromModel(FeatureSelector):
     """Selects top features based on importance weights using a Random Forest regressor."""
@@ -15,7 +17,10 @@ class RFRegressorSelectFromModel(FeatureSelector):
     }
 
     def __init__(self, number_features=None, n_estimators=10, max_depth=None,
-                 percent_features=0.5, threshold=-np.inf, n_jobs=-1, random_state=0, **kwargs):
+                 percent_features=0.5, threshold=-np.inf, n_jobs=-1,
+                 random_state=None, random_seed=0, **kwargs):
+        random_seed = deprecate_arg("random_state", "random_seed", random_state, random_seed)
+
         parameters = {"number_features": number_features,
                       "n_estimators": n_estimators,
                       "max_depth": max_depth,
@@ -24,7 +29,7 @@ class RFRegressorSelectFromModel(FeatureSelector):
                       "n_jobs": n_jobs}
         parameters.update(kwargs)
 
-        estimator = SKRandomForestRegressor(random_state=random_state,
+        estimator = SKRandomForestRegressor(random_state=random_seed,
                                             n_estimators=n_estimators,
                                             max_depth=max_depth,
                                             n_jobs=n_jobs)
@@ -35,4 +40,4 @@ class RFRegressorSelectFromModel(FeatureSelector):
                                      **kwargs)
         super().__init__(parameters=parameters,
                          component_obj=feature_selection,
-                         random_state=random_state)
+                         random_seed=random_seed)
