@@ -1,8 +1,9 @@
 from evalml.pipelines.components.transformers import Transformer
 from evalml.pipelines.components.transformers.imputers import SimpleImputer
-from evalml.utils.gen_utils import (
-    _convert_to_woodwork_structure,
-    _convert_woodwork_types_wrapper
+from evalml.utils import (
+    _convert_woodwork_types_wrapper,
+    _retain_custom_types_and_initalize_woodwork,
+    infer_feature_types
 )
 
 
@@ -20,7 +21,8 @@ class Imputer(Transformer):
                  categorical_fill_value=None,
                  numeric_impute_strategy="mean",
                  numeric_fill_value=None,
-                 random_state=0, **kwargs):
+                 random_state=None,
+                 random_seed=0, **kwargs):
         """Initalizes an transformer that imputes missing data according to the specified imputation strategy."
 
         Arguments:
@@ -50,7 +52,8 @@ class Imputer(Transformer):
         self._categorical_cols = None
         super().__init__(parameters=parameters,
                          component_obj=None,
-                         random_state=random_state)
+                         random_state=random_state,
+                         random_seed=random_seed)
 
     def fit(self, X, y=None):
         """Fits imputer to data. 'None' values are converted to np.nan before imputation and are
@@ -63,8 +66,8 @@ class Imputer(Transformer):
         Returns:
             self
         """
-        X = _convert_to_woodwork_structure(X)
-        cat_cols = list(X.select('category').columns)
+        X = infer_feature_types(X)
+        cat_cols = list(X.select(['category', 'boolean']).columns)
         numeric_cols = list(X.select('numeric').columns)
 
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
@@ -95,13 +98,11 @@ class Imputer(Transformer):
         Returns:
             ww.DataTable: Transformed X
         """
-        X = _convert_to_woodwork_structure(X)
-        X = _convert_woodwork_types_wrapper(X.to_dataframe())
-
-        X_null_dropped = X.copy()
+        X_ww = infer_feature_types(X)
+        X_null_dropped = _convert_woodwork_types_wrapper(X_ww.to_dataframe())
         X_null_dropped.drop(self._all_null_cols, inplace=True, axis=1, errors='ignore')
         if X_null_dropped.empty:
-            return _convert_to_woodwork_structure(X_null_dropped)
+            return _retain_custom_types_and_initalize_woodwork(X_ww, X_null_dropped)
 
         if self._numeric_cols is not None and len(self._numeric_cols) > 0:
             X_numeric = X_null_dropped[self._numeric_cols]
@@ -112,6 +113,5 @@ class Imputer(Transformer):
             X_categorical = X_null_dropped[self._categorical_cols]
             imputed = self._categorical_imputer.transform(X_categorical).to_dataframe()
             X_null_dropped[X_categorical.columns] = imputed
-
-        X_null_dropped = _convert_to_woodwork_structure(X_null_dropped)
+        X_null_dropped = _retain_custom_types_and_initalize_woodwork(X_ww, X_null_dropped)
         return X_null_dropped
