@@ -3,5 +3,5 @@ from .drop_null_columns import DropNullColumns
 from .text_transformer import TextTransformer
 from .lsa import LSA
 from .text_featurizer import TextFeaturizer
-from .time_series import DelayedFeatureTransformer
+from .delayed_feature_transformer import DelayedFeatureTransformer
 from .featuretools import DFSTransformer
