@@ -2,6 +2,7 @@ import pandas as pd
 
 from evalml.objectives import get_objective
 from evalml.pipelines.classification_pipeline import ClassificationPipeline
+from evalml.pipelines.pipeline_meta import TimeSeriesPipelineBaseMeta
 from evalml.problem_types import ProblemTypes
 from evalml.utils import (
     _convert_woodwork_types_wrapper,
@@ -11,7 +12,7 @@ from evalml.utils import (
 )
 
 
-class TimeSeriesClassificationPipeline(ClassificationPipeline):
+class TimeSeriesClassificationPipeline(ClassificationPipeline, metaclass=TimeSeriesPipelineBaseMeta):
     """Pipeline base class for time series classifcation problems."""
 
     def __init__(self, parameters, random_state=None, random_seed=0):
@@ -63,6 +64,7 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
         y_shifted = y.shift(-self.gap)
         X_t, y_shifted = drop_rows_with_nans(X_t, y_shifted)
         self.estimator.fit(X_t, y_shifted)
+        self.input_feature_names = self._component_graph.input_feature_names
         return self
 
     def _estimator_predict(self, features, y):
@@ -152,7 +154,7 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
         X, y = self._convert_to_woodwork(X, y)
         X = _convert_woodwork_types_wrapper(X.to_dataframe())
         y = _convert_woodwork_types_wrapper(y.to_series())
-        objectives = [get_objective(o, return_instance=True) for o in objectives]
+        objectives = self.create_objectives(objectives)
 
         y_encoded = self._encode_targets(y)
         y_shifted = y_encoded.shift(-self.gap)
@@ -167,7 +169,7 @@ class TimeSeriesClassificationPipeline(ClassificationPipeline):
                                           objectives=objectives)
 
 
-class TimeSeriesBinaryClassificationPipeline(TimeSeriesClassificationPipeline):
+class TimeSeriesBinaryClassificationPipeline(TimeSeriesClassificationPipeline, metaclass=TimeSeriesPipelineBaseMeta):
     problem_type = ProblemTypes.TIME_SERIES_BINARY
     _threshold = None
 
