@@ -1,14 +1,6 @@
 import json
 
 from .binary_classification_pipeline import BinaryClassificationPipeline
-from .generated_pipelines import (
-    GeneratedPipelineBinary,
-    GeneratedPipelineMulticlass,
-    GeneratedPipelineRegression,
-    GeneratedPipelineTimeSeriesBinary,
-    GeneratedPipelineTimeSeriesMulticlass,
-    GeneratedPipelineTimeSeriesRegression
-)
 from .multiclass_classification_pipeline import (
     MulticlassClassificationPipeline
 )
@@ -19,6 +11,7 @@ from .time_series_classification_pipelines import (
 )
 from .time_series_regression_pipeline import TimeSeriesRegressionPipeline
 
+from evalml.data_checks import DataCheckActionCode
 from evalml.model_family import ModelFamily
 from evalml.pipelines import PipelineBase
 from evalml.pipelines.components import (  # noqa: F401
@@ -27,6 +20,7 @@ from evalml.pipelines.components import (  # noqa: F401
     ComponentBase,
     DateTimeFeaturizer,
     DelayedFeatureTransformer,
+    DropColumns,
     DropNullColumns,
     Estimator,
     Imputer,
@@ -146,26 +140,6 @@ def make_pipeline(X, y, estimator, problem_type, custom_hyperparameters=None):
     return GeneratedPipeline
 
 
-def get_generated_pipeline_class(problem_type):
-    """Returns the class for the generated pipeline based on the problem type
-
-    Arguments:
-        problem_type (ProblemTypes): The problem_type that the pipeline is for
-
-    Returns:
-        GeneratedPipelineClass (GeneratedPipelineClass): The generated pipeline class for the problem type
-    """
-    try:
-        return {ProblemTypes.BINARY: GeneratedPipelineBinary,
-                ProblemTypes.MULTICLASS: GeneratedPipelineMulticlass,
-                ProblemTypes.REGRESSION: GeneratedPipelineRegression,
-                ProblemTypes.TIME_SERIES_REGRESSION: GeneratedPipelineTimeSeriesRegression,
-                ProblemTypes.TIME_SERIES_BINARY: GeneratedPipelineTimeSeriesBinary,
-                ProblemTypes.TIME_SERIES_MULTICLASS: GeneratedPipelineTimeSeriesMulticlass}[problem_type]
-    except KeyError:
-        raise ValueError("ProblemType {} not recognized".format(problem_type))
-
-
 def make_pipeline_from_components(component_instances, problem_type, custom_name=None, random_state=None, random_seed=0):
     """Given a list of component instances and the problem type, an pipeline instance is generated with the component instances.
     The pipeline will be a subclass of the appropriate pipeline base class for the specified problem_type. The pipeline will be
@@ -276,3 +250,20 @@ def _make_stacked_ensemble_pipeline(input_pipelines, problem_type, n_jobs=-1, ra
         return make_pipeline_from_components([StackedEnsembleRegressor(input_pipelines, n_jobs=n_jobs)], problem_type,
                                              custom_name="Stacked Ensemble Regression Pipeline",
                                              random_seed=random_seed)
+
+
+def _make_component_list_from_actions(actions):
+    """
+    Creates a list of components from the input DataCheckAction list
+
+    Arguments:
+        actions (list(DataCheckAction)): List of DataCheckAction objects used to create list of components
+
+    Returns:
+        List of components used to address the input actions
+    """
+    components = []
+    for action in actions:
+        if action.action_code == DataCheckActionCode.DROP_COL:
+            components.append(DropColumns(columns=action.details["columns"]))
+    return components
