@@ -108,7 +108,7 @@ def test_iterative_algorithm_results(mock_stack, ensembling_value, dummy_binary_
     # the "best" score will be the 1st dummy pipeline
     scores = np.arange(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
     # subsequent batches contain pipelines_per_batch copies of one pipeline, moving from best to worst from the first batch
     last_batch_number = algo.batch_number
@@ -131,7 +131,8 @@ def test_iterative_algorithm_results(mock_stack, ensembling_value, dummy_binary_
             all_parameters.extend([p.parameters for p in next_batch])
             scores = -np.arange(0, len(next_batch))
             for score, pipeline in zip(scores, next_batch):
-                algo.add_result(score, pipeline)
+                algo.add_result(score, pipeline, {"id": algo.pipeline_number})
+
         assert any([p != dummy_binary_pipeline_classes[0]({}).parameters for p in all_parameters])
 
         if ensembling_value:
@@ -145,7 +146,7 @@ def test_iterative_algorithm_results(mock_stack, ensembling_value, dummy_binary_
             last_pipeline_number = algo.pipeline_number
             scores = np.arange(0, len(next_batch))
             for score, pipeline in zip(scores, next_batch):
-                algo.add_result(score, pipeline)
+                algo.add_result(score, pipeline, {"id": algo.pipeline_number})
             assert pipeline.model_family == ModelFamily.ENSEMBLE
             assert pipeline.random_seed == algo.random_seed
             stack_args = mock_stack.call_args[1]['estimators']
@@ -153,6 +154,7 @@ def test_iterative_algorithm_results(mock_stack, ensembling_value, dummy_binary_
             random_seeds_the_same = [(estimator.pipeline.random_seed == algo.random_seed)
                                      for estimator in estimators_used_in_ensemble]
             assert all(random_seeds_the_same)
+            assert ModelFamily.ENSEMBLE not in algo._best_pipeline_info
 
 
 @pytest.mark.parametrize("ensembling_value", [True, False])
@@ -168,7 +170,7 @@ def test_iterative_algorithm_passes_pipeline_params(mock_stack, ensembling_value
     # the "best" score will be the 1st dummy pipeline
     scores = np.arange(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
     for i in range(1, 5):
         for _ in range(len(dummy_binary_pipeline_classes)):
@@ -176,7 +178,7 @@ def test_iterative_algorithm_passes_pipeline_params(mock_stack, ensembling_value
             assert all([p.parameters['pipeline'] == {"gap": 2, "max_delay": 10} for p in next_batch])
             scores = -np.arange(0, len(next_batch))
             for score, pipeline in zip(scores, next_batch):
-                algo.add_result(score, pipeline)
+                algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
         if ensembling_value:
             next_batch = algo.next_batch()
@@ -192,7 +194,7 @@ def test_iterative_algorithm_passes_njobs(dummy_binary_pipeline_classes):
     # the "best" score will be the 1st dummy pipeline
     scores = np.arange(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
     for i in range(1, 3):
         for _ in range(len(dummy_binary_pipeline_classes)):
@@ -200,7 +202,7 @@ def test_iterative_algorithm_passes_njobs(dummy_binary_pipeline_classes):
             assert all([p.parameters['Mock Classifier']['n_jobs'] == 2 for p in next_batch])
             scores = -np.arange(0, len(next_batch))
             for score, pipeline in zip(scores, next_batch):
-                algo.add_result(score, pipeline)
+                algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
 
 @pytest.mark.parametrize("ensembling_value", [True, False])
@@ -221,7 +223,7 @@ def test_iterative_algorithm_one_allowed_pipeline(ensembling_value, logistic_reg
     # the "best" score will be the 1st dummy pipeline
     scores = np.arange(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
     # subsequent batches contain pipelines_per_batch copies of one pipeline, moving from best to worst from the first batch
     last_batch_number = algo.batch_number
@@ -239,7 +241,8 @@ def test_iterative_algorithm_one_allowed_pipeline(ensembling_value, logistic_reg
         all_parameters.extend([p.parameters for p in next_batch])
         scores = -np.arange(0, len(next_batch))
         for score, pipeline in zip(scores, next_batch):
-            algo.add_result(score, pipeline)
+            algo.add_result(score, pipeline, {"id": algo.pipeline_number})
+
         assert any([p != logistic_regression_binary_pipeline_class.default_parameters for p in all_parameters])
 
 
@@ -251,7 +254,8 @@ def test_iterative_algorithm_stacked_ensemble_n_jobs_binary(n_jobs, dummy_binary
     seen_ensemble = False
     scores = range(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
+
     for i in range(5):
         next_batch = algo.next_batch()
         for pipeline in next_batch:
@@ -268,7 +272,8 @@ def test_iterative_algorithm_stacked_ensemble_n_jobs_regression(n_jobs, linear_r
     seen_ensemble = False
     scores = range(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
+
     for i in range(5):
         next_batch = algo.next_batch()
         for pipeline in next_batch:
@@ -294,7 +299,7 @@ def test_iterative_algorithm_pipeline_params(parameters, dummy_binary_pipeline_c
 
     scores = np.arange(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
     # make sure that future batches remain in the hyperparam range
     for i in range(1, 5):
@@ -324,7 +329,7 @@ def test_iterative_algorithm_pipeline_params_skopt(parameters, dummy_binary_pipe
 
     scores = np.arange(0, len(next_batch))
     for score, pipeline in zip(scores, next_batch):
-        algo.add_result(score, pipeline)
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number})
 
     # make sure that future batches remain in the hyperparam range
     for i in range(1, 5):
@@ -346,3 +351,23 @@ def test_iterative_algorithm_pipeline_params_kwargs(dummy_binary_pipeline_classe
 
     next_batch = algo.next_batch()
     assert all([p.parameters['Mock Classifier'] == {"dummy_parameter": "dummy", "n_jobs": -1, "fake_param": "fake"} for p in next_batch])
+
+
+def test_iterative_algorithm_results_best_pipeline_info_id(dummy_binary_pipeline_classes, logistic_regression_binary_pipeline_class):
+    allowed_pipelines = [dummy_binary_pipeline_classes()[0], logistic_regression_binary_pipeline_class]
+    algo = IterativeAlgorithm(allowed_pipelines=allowed_pipelines)
+
+    # initial batch contains one of each pipeline, with default parameters
+    next_batch = algo.next_batch()
+    scores = np.arange(0, len(next_batch))
+    for pipeline_num, (score, pipeline) in enumerate(zip(scores, next_batch)):
+        algo.add_result(score, pipeline, {"id": algo.pipeline_number + pipeline_num})
+    assert algo._best_pipeline_info[ModelFamily.RANDOM_FOREST]['id'] == 2
+    assert algo._best_pipeline_info[ModelFamily.LINEAR_MODEL]['id'] == 3
+
+    for i in range(1, 3):
+        next_batch = algo.next_batch()
+        scores = -np.arange(1, len(next_batch))  # Score always gets better with each pipeline
+        for pipeline_num, (score, pipeline) in enumerate(zip(scores, next_batch)):
+            algo.add_result(score, pipeline, {"id": algo.pipeline_number + pipeline_num})
+            assert algo._best_pipeline_info[pipeline.model_family]['id'] == algo.pipeline_number + pipeline_num
