@@ -3,13 +3,21 @@ import pandas as pd
 import pytest
 import woodwork as ww
 from pandas.testing import assert_frame_equal
+from woodwork.logical_types import (
+    Boolean,
+    Categorical,
+    Datetime,
+    Double,
+    Integer,
+    NaturalLanguage
+)
 
 from evalml.exceptions import ComponentNotYetFittedError
 from evalml.pipelines.components import OneHotEncoder
 from evalml.utils import (
-    _convert_to_woodwork_structure,
     _convert_woodwork_types_wrapper,
-    get_random_seed
+    get_random_seed,
+    infer_feature_types
 )
 
 
@@ -184,7 +192,7 @@ def test_no_top_n():
     for val in X["col_2"]:
         expected_col_names.add("col_2_" + val)
 
-    encoder = OneHotEncoder(top_n=None, handle_unknown="error", random_state=2)
+    encoder = OneHotEncoder(top_n=None, handle_unknown="error", random_seed=2)
     encoder.fit(X)
     X_t = encoder.transform(X)
 
@@ -214,7 +222,7 @@ def test_categories():
                   ["a", "b"]]
 
     # test categories value works
-    encoder = OneHotEncoder(top_n=None, categories=categories, random_state=2)
+    encoder = OneHotEncoder(top_n=None, categories=categories, random_seed=2)
     encoder.fit(X)
     X_t = encoder.transform(X)
 
@@ -227,7 +235,7 @@ def test_categories():
 
     # test categories with top_n errors
     with pytest.raises(ValueError, match="Cannot use categories and top_n arguments simultaneously"):
-        encoder = OneHotEncoder(top_n=10, categories=categories, random_state=2)
+        encoder = OneHotEncoder(top_n=10, categories=categories, random_seed=2)
 
 
 def test_less_than_top_n_unique_values():
@@ -255,12 +263,12 @@ def test_more_top_n_unique_values():
 
     random_seed = 2
 
-    encoder = OneHotEncoder(top_n=5, random_state=random_seed)
+    encoder = OneHotEncoder(top_n=5, random_seed=random_seed)
     encoder.fit(X)
     X_t = encoder.transform(X)
 
     # Conversion changes the resulting dataframe dtype, resulting in a different random state, so we need make the conversion here too
-    X = _convert_to_woodwork_structure(X)
+    X = infer_feature_types(X)
     X = _convert_woodwork_types_wrapper(X.to_dataframe())
     col_1_counts = X["col_1"].value_counts(dropna=False).to_frame()
     col_1_counts = col_1_counts.sample(frac=1, random_state=random_seed)
@@ -289,17 +297,16 @@ def test_more_top_n_unique_values_large():
                       "col_4": [2, 0, 1, 3, 0, 1, 2, 4, 1]})
 
     random_seed = 2
-    test_random_state = get_random_seed(random_seed)
 
-    encoder = OneHotEncoder(top_n=3, random_state=random_seed)
+    encoder = OneHotEncoder(top_n=3, random_seed=random_seed)
     encoder.fit(X)
     X_t = encoder.transform(X)
 
     # Conversion changes the resulting dataframe dtype, resulting in a different random state, so we need make the conversion here too
-    X = _convert_to_woodwork_structure(X)
+    X = infer_feature_types(X)
     X = _convert_woodwork_types_wrapper(X.to_dataframe())
     col_1_counts = X["col_1"].value_counts(dropna=False).to_frame()
-    col_1_counts = col_1_counts.sample(frac=1, random_state=test_random_state)
+    col_1_counts = col_1_counts.sample(frac=1, random_state=random_seed)
     col_1_counts = col_1_counts.sort_values(["col_1"], ascending=False, kind='mergesort')
     col_1_samples = col_1_counts.head(encoder.parameters['top_n']).index.tolist()
     expected_col_names = set(["col_2_a", "col_2_b", "col_2_c", "col_3_a", "col_3_b", "col_3_c", "col_4"])
@@ -473,8 +480,8 @@ def test_ohe_top_n_categories_always_the_same():
     df = pd.DataFrame({"categories": ["cat_1"] * 5 + ["cat_2"] * 4 + ["cat_3"] * 3 + ["cat_4"] * 3 + ["cat_5"] * 3,
                        "numbers": range(18)})
 
-    def check_df_equality(random_state):
-        ohe = OneHotEncoder(top_n=4, random_state=random_state)
+    def check_df_equality(random_seed):
+        ohe = OneHotEncoder(top_n=4, random_seed=random_seed)
         df1 = ohe.fit_transform(df).to_dataframe()
         df2 = ohe.fit_transform(df).to_dataframe()
         assert_frame_equal(df1, df2)
@@ -493,3 +500,26 @@ def test_ohe_column_names_unique():
     # category y_1 in A_x gets mapped to A_x_y_1_1 because A_x_y_1 already exists
     # category 1 in A_x_y gets mapped to A_x_y_1_2 because A_x_y_1_1 already exists
     assert set(df_transformed.columns) == {"A_x_y", "A_z", "A_x_y_1", "A_x_y_1_1", "A_x_y_1_2", "A_x_y_y"}
+
+
+@pytest.mark.parametrize("X_df", [pd.DataFrame(pd.to_datetime(['20190902', '20200519', '20190607'], format='%Y%m%d')),
+                                  pd.DataFrame(pd.Series([1, 2, 3], dtype="Int64")),
+                                  pd.DataFrame(pd.Series([1., 2., 3.], dtype="float")),
+                                  pd.DataFrame(pd.Series(['a', 'b', 'a'], dtype="category")),
+                                  pd.DataFrame(pd.Series([True, False, True], dtype="boolean")),
+                                  pd.DataFrame(pd.Series(['this will be a natural language column because length', 'yay', 'hay'], dtype="string"))])
+def test_ohe_woodwork_custom_overrides_returned_by_components(X_df):
+    y = pd.Series([1, 2, 1])
+    override_types = [Integer, Double, Categorical, NaturalLanguage, Datetime, Boolean]
+    for logical_type in override_types:
+        try:
+            X = ww.DataTable(X_df, logical_types={0: logical_type})
+        except TypeError:
+            continue
+
+        ohe = OneHotEncoder()
+        ohe.fit(X, y)
+        transformed = ohe.transform(X, y)
+        assert isinstance(transformed, ww.DataTable)
+        if logical_type != Categorical:
+            assert transformed.logical_types == {0: logical_type}
