@@ -1,7 +1,15 @@
 import numpy as np
 import pandas as pd
 import pytest
+import woodwork as ww
 from pandas.testing import assert_frame_equal
+from woodwork.logical_types import (
+    Boolean,
+    Categorical,
+    Double,
+    Integer,
+    NaturalLanguage
+)
 
 from evalml.pipelines.components import SimpleImputer
 
@@ -116,8 +124,8 @@ def test_simple_imputer_all_bool_return_original(data_type, make_data_type):
 
 
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
-def test_simple_imputer_bool_dtype_object(data_type, make_data_type):
-    X = pd.DataFrame([True, np.nan, False, np.nan, True], dtype=object)
+def test_simple_imputer_boolean_dtype(data_type, make_data_type):
+    X = pd.DataFrame([True, np.nan, False, np.nan, True], dtype='boolean')
     y = pd.Series([1, 0, 0, 1, 0])
     X_expected_arr = pd.DataFrame([True, True, False, True, True], dtype='boolean')
     X = make_data_type(data_type, X)
@@ -130,7 +138,7 @@ def test_simple_imputer_bool_dtype_object(data_type, make_data_type):
 @pytest.mark.parametrize("data_type", ['pd', 'ww'])
 def test_simple_imputer_multitype_with_one_bool(data_type, make_data_type):
     X_multi = pd.DataFrame({
-        "bool with nan": pd.Series([True, np.nan, False, np.nan, False], dtype=object),
+        "bool with nan": pd.Series([True, np.nan, False, np.nan, False], dtype='boolean'),
         "bool no nan": pd.Series([False, False, False, False, True], dtype=bool),
     })
     y = pd.Series([1, 0, 0, 1, 0])
@@ -264,7 +272,7 @@ def test_simple_imputer_with_none():
     assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
 
     X = pd.DataFrame({"category with None": pd.Series(["b", "a", "a", None], dtype='category'),
-                      "boolean with None": [True, None, False, True],
+                      "boolean with None": pd.Series([True, None, False, True], dtype='boolean'),
                       "object with None": ["b", "a", "a", None],
                       "all None": [None, None, None, None]})
     y = pd.Series([0, 0, 1, 0, 1])
@@ -275,3 +283,35 @@ def test_simple_imputer_with_none():
                              "boolean with None": pd.Series([True, True, False, True], dtype='boolean'),
                              "object with None": pd.Series(["b", "a", "a", "a"], dtype='category')})
     assert_frame_equal(expected, transformed.to_dataframe(), check_dtype=False)
+
+
+@pytest.mark.parametrize("X_df", [pd.DataFrame(pd.Series([1, 2, 3], dtype="Int64")),
+                                  pd.DataFrame(pd.Series([1., 2., 3.], dtype="float")),
+                                  pd.DataFrame(pd.Series(['a', 'b', 'a'], dtype="category")),
+                                  pd.DataFrame(pd.Series([True, False, True], dtype="boolean")),
+                                  pd.DataFrame(pd.Series(['this will be a natural language column because length', 'yay', 'hay'], dtype="string"))])
+@pytest.mark.parametrize("has_nan", [True, False])
+@pytest.mark.parametrize("impute_strategy", ["mean", "median", "most_frequent"])
+def test_simple_imputer_woodwork_custom_overrides_returned_by_components(X_df, has_nan, impute_strategy):
+    y = pd.Series([1, 2, 1])
+    if has_nan:
+        X_df.iloc[len(X_df) - 1, 0] = np.nan
+    override_types = [Integer, Double, Categorical, NaturalLanguage, Boolean]
+    for logical_type in override_types:
+        try:
+            X = ww.DataTable(X_df, logical_types={0: logical_type})
+        except TypeError:
+            continue
+
+        impute_strategy_to_use = impute_strategy
+        if logical_type in [NaturalLanguage, Categorical]:
+            impute_strategy_to_use = "most_frequent"
+
+        imputer = SimpleImputer(impute_strategy=impute_strategy_to_use)
+        imputer.fit(X, y)
+        transformed = imputer.transform(X, y)
+        assert isinstance(transformed, ww.DataTable)
+        if impute_strategy_to_use == "most_frequent" or not has_nan:
+            assert transformed.logical_types == {0: logical_type}
+        else:
+            assert transformed.logical_types == {0: Double}
