@@ -87,15 +87,15 @@ def test_stacked_ensemble_n_jobs_negative_one(X_y_regression, linear_regression_
 
 
 @patch('evalml.pipelines.components.ensemble.StackedEnsembleRegressor._stacking_estimator_class')
-def test_stacked_ensemble_does_not_overwrite_pipeline_random_state(mock_stack,
-                                                                   linear_regression_pipeline_class):
-    input_pipelines = [linear_regression_pipeline_class(parameters={}, random_state=3),
-                       linear_regression_pipeline_class(parameters={}, random_state=4)]
-    clf = StackedEnsembleRegressor(input_pipelines=input_pipelines, random_state=5, n_jobs=1)
+def test_stacked_ensemble_does_not_overwrite_pipeline_random_seed(mock_stack,
+                                                                  linear_regression_pipeline_class):
+    input_pipelines = [linear_regression_pipeline_class(parameters={}, random_seed=3),
+                       linear_regression_pipeline_class(parameters={}, random_seed=4)]
+    clf = StackedEnsembleRegressor(input_pipelines=input_pipelines, random_seed=5, n_jobs=1)
     estimators_used_in_ensemble = mock_stack.call_args[1]['estimators']
-    assert clf.random_state == 5
-    assert estimators_used_in_ensemble[0][1].pipeline.random_state == 3
-    assert estimators_used_in_ensemble[1][1].pipeline.random_state == 4
+    assert clf.random_seed == 5
+    assert estimators_used_in_ensemble[0][1].pipeline.random_seed == 3
+    assert estimators_used_in_ensemble[1][1].pipeline.random_seed == 4
 
 
 def test_stacked_ensemble_multilevel(linear_regression_pipeline_class):
