@@ -28,6 +28,9 @@ def test_class_imbalance_errors():
     with pytest.raises(ValueError, match="Provided number of CV folds"):
         ClassImbalanceDataCheck(num_cv_folds=-1).validate(X, y=pd.Series([0, 1, 1]))
 
+    with pytest.raises(ValueError, match="Provided value min_samples"):
+        ClassImbalanceDataCheck(min_samples=-1).validate(X, y=pd.Series([0, 1, 1]))
+
 
 @pytest.mark.parametrize("input_type", ["pd", "np", "ww"])
 def test_class_imbalance_data_check_binary(input_type):
@@ -48,21 +51,23 @@ def test_class_imbalance_data_check_binary(input_type):
         y_long = ww.DataColumn(y_long)
         y_balanced = ww.DataColumn(y_balanced)
 
-    class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=0)
-    assert class_imbalance_check.validate(X, y) == {"warnings": [], "errors": []}
+    class_imbalance_check = ClassImbalanceDataCheck(min_samples=1, num_cv_folds=0)
+    assert class_imbalance_check.validate(X, y) == {"warnings": [], "errors": [], "actions": []}
     assert class_imbalance_check.validate(X, y_long) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 10% of the target: [0]",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
                                       details={"target_values": [0]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
-    assert ClassImbalanceDataCheck(threshold=0.25, num_cv_folds=0).validate(X, y_long) == {
+    assert ClassImbalanceDataCheck(threshold=0.25, min_samples=1, num_cv_folds=0).validate(X, y_long) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 25% of the target: [0]",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
                                       details={"target_values": [0]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=1)
@@ -71,10 +76,11 @@ def test_class_imbalance_data_check_binary(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 2 instances: [1]",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": [1]}).to_dict()]
+                                  details={"target_values": [1]}).to_dict()],
+        "actions": []
     }
 
-    assert class_imbalance_check.validate(X, y_balanced) == {"warnings": [], "errors": []}
+    assert class_imbalance_check.validate(X, y_balanced) == {"warnings": [], "errors": [], "actions": []}
 
     class_imbalance_check = ClassImbalanceDataCheck()
     assert class_imbalance_check.validate(X, y) == {
@@ -82,7 +88,8 @@ def test_class_imbalance_data_check_binary(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [0, 1]",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": [0, 1]}).to_dict()]
+                                  details={"target_values": [0, 1]}).to_dict()],
+        "actions": []
     }
 
 
@@ -112,21 +119,27 @@ def test_class_imbalance_data_check_multiclass(input_type):
         y_long = ww.DataColumn(y_long)
 
     class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=0)
-    assert class_imbalance_check.validate(X, y) == {"warnings": [], "errors": []}
+    assert class_imbalance_check.validate(X, y) == {"warnings": [], "errors": [], "actions": []}
     assert class_imbalance_check.validate(X, y_imbalanced_default_threshold) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 10% of the target: [0]",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
+                                      details={"target_values": [0]}).to_dict(),
+                     DataCheckWarning(message="The following labels in the target have severe class imbalance because they fall under 10% of the target and have less than 100 samples: [0]",
+                                      data_check_name=class_imbalance_data_check_name,
+                                      message_code=DataCheckMessageCode.CLASS_IMBALANCE_SEVERE,
                                       details={"target_values": [0]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
-    assert ClassImbalanceDataCheck(threshold=0.25, num_cv_folds=0).validate(X, y_imbalanced_set_threshold) == {
+    assert ClassImbalanceDataCheck(threshold=0.25, num_cv_folds=0, min_samples=1).validate(X, y_imbalanced_set_threshold) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 25% of the target: [3, 0]",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
                                       details={"target_values": [3, 0]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=2)
@@ -135,7 +148,8 @@ def test_class_imbalance_data_check_multiclass(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 4 instances: [2, 0]",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": [2, 0]}).to_dict()]
+                                  details={"target_values": [2, 0]}).to_dict()],
+        "actions": []
     }
 
     assert class_imbalance_check.validate(X, y_long) == {
@@ -143,7 +157,8 @@ def test_class_imbalance_data_check_multiclass(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 4 instances: [1, 0]",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": [1, 0]}).to_dict()]
+                                  details={"target_values": [1, 0]}).to_dict()],
+        "actions": []
     }
 
     class_imbalance_check = ClassImbalanceDataCheck()
@@ -152,7 +167,8 @@ def test_class_imbalance_data_check_multiclass(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: [3, 2, 1, 0]",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": [3, 2, 1, 0]}).to_dict()]
+                                  details={"target_values": [3, 2, 1, 0]}).to_dict()],
+        "actions": []
     }
 
 
@@ -173,26 +189,45 @@ def test_class_imbalance_empty_and_nan(input_type):
         y_has_nan = ww.DataColumn(y_has_nan)
     class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=0)
 
-    assert class_imbalance_check.validate(X, y_empty) == {"warnings": [], "errors": []}
+    assert class_imbalance_check.validate(X, y_empty) == {"warnings": [], "errors": [], "actions": []}
+    assert ClassImbalanceDataCheck(threshold=0.5, min_samples=1, num_cv_folds=0).validate(X, y_has_nan) == {
+        "warnings": [DataCheckWarning(message="The following labels fall below 50% of the target: [2.0]",
+                                      data_check_name=class_imbalance_data_check_name,
+                                      message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
+                                      details={"target_values": [2.0]}).to_dict()],
+        "errors": [],
+        "actions": []
+    }
+
     assert ClassImbalanceDataCheck(threshold=0.5, num_cv_folds=0).validate(X, y_has_nan) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 50% of the target: [2.0]",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
+                                      details={"target_values": [2.0]}).to_dict(),
+                     DataCheckWarning(message="The following labels in the target have severe class imbalance because they fall under 50% of the target and have less than 100 samples: [2.0]",
+                                      data_check_name=class_imbalance_data_check_name,
+                                      message_code=DataCheckMessageCode.CLASS_IMBALANCE_SEVERE,
                                       details={"target_values": [2.0]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=1)
-    assert class_imbalance_check.validate(X, y_empty) == {"warnings": [], "errors": []}
+    assert class_imbalance_check.validate(X, y_empty) == {"warnings": [], "errors": [], "actions": []}
     assert ClassImbalanceDataCheck(threshold=0.5, num_cv_folds=1).validate(X, y_has_nan) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 50% of the target: [2.0]",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
+                                      details={"target_values": [2.0]}).to_dict(),
+                     DataCheckWarning(message="The following labels in the target have severe class imbalance because they fall under 50% of the target and have less than 100 samples: [2.0]",
+                                      data_check_name=class_imbalance_data_check_name,
+                                      message_code=DataCheckMessageCode.CLASS_IMBALANCE_SEVERE,
                                       details={"target_values": [2.0]}).to_dict()],
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 2 instances: [2.0]",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": [2.0]}).to_dict()]
+                                  details={"target_values": [2.0]}).to_dict()],
+        "actions": []
     }
 
 
@@ -210,13 +245,14 @@ def test_class_imbalance_nonnumeric(input_type):
         y_binary = ww.DataColumn(y_binary)
         y_multiclass = ww.DataColumn(y_multiclass)
 
-    class_imbalance_check = ClassImbalanceDataCheck(threshold=0.25, num_cv_folds=0)
+    class_imbalance_check = ClassImbalanceDataCheck(threshold=0.25, min_samples=1, num_cv_folds=0)
     assert class_imbalance_check.validate(X, y_bools) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 25% of the target: [True]",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
                                       details={"target_values": [True]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     assert class_imbalance_check.validate(X, y_binary) == {
@@ -224,15 +260,21 @@ def test_class_imbalance_nonnumeric(input_type):
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
                                       details={"target_values": ["no"]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     assert ClassImbalanceDataCheck(threshold=0.35, num_cv_folds=0).validate(X, y_multiclass) == {
         "warnings": [DataCheckWarning(message="The following labels fall below 35% of the target: ['green', 'blue']",
                                       data_check_name=class_imbalance_data_check_name,
                                       message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
+                                      details={"target_values": ["green", "blue"]}).to_dict(),
+                     DataCheckWarning(message="The following labels in the target have severe class imbalance because they fall under 35% of the target and have less than 100 samples: ['green', 'blue']",
+                                      data_check_name=class_imbalance_data_check_name,
+                                      message_code=DataCheckMessageCode.CLASS_IMBALANCE_SEVERE,
                                       details={"target_values": ["green", "blue"]}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=1)
@@ -241,9 +283,10 @@ def test_class_imbalance_nonnumeric(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 2 instances: ['Yes']",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": ["Yes"]}).to_dict()]
+                                  details={"target_values": ["Yes"]}).to_dict()],
+        "actions": []
     }
-    assert class_imbalance_check.validate(X, y_multiclass) == {"warnings": [], "errors": []}
+    assert class_imbalance_check.validate(X, y_multiclass) == {"warnings": [], "errors": [], "actions": []}
 
     class_imbalance_check = ClassImbalanceDataCheck()
     assert class_imbalance_check.validate(X, y_binary_imbalanced_folds) == {
@@ -251,7 +294,8 @@ def test_class_imbalance_nonnumeric(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: ['No', 'Yes']",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": ["No", "Yes"]}).to_dict()]
+                                  details={"target_values": ["No", "Yes"]}).to_dict()],
+        "actions": []
     }
 
     assert class_imbalance_check.validate(X, y_multiclass) == {
@@ -259,7 +303,8 @@ def test_class_imbalance_nonnumeric(input_type):
         "errors": [DataCheckError(message="The number of instances of these targets is less than 2 * the number of cross folds = 6 instances: ['red', 'green', 'blue']",
                                   data_check_name=class_imbalance_data_check_name,
                                   message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_FOLDS,
-                                  details={"target_values": ["red", "green", "blue"]}).to_dict()]
+                                  details={"target_values": ["red", "green", "blue"]}).to_dict()],
+        "actions": []
     }
 
 
@@ -276,6 +321,41 @@ def test_class_imbalance_nonnumeric_balanced(input_type):
         y_multiclass_balanced = ww.DataColumn(y_multiclass_balanced)
 
     class_imbalance_check = ClassImbalanceDataCheck(num_cv_folds=1)
-    assert class_imbalance_check.validate(X, y_multiclass_balanced) == {"warnings": [], "errors": []}
-    assert class_imbalance_check.validate(X, y_binary_balanced) == {"warnings": [], "errors": []}
-    assert class_imbalance_check.validate(X, y_multiclass_balanced) == {"warnings": [], "errors": []}
+    assert class_imbalance_check.validate(X, y_multiclass_balanced) == {"warnings": [], "errors": [], "actions": []}
+    assert class_imbalance_check.validate(X, y_binary_balanced) == {"warnings": [], "errors": [], "actions": []}
+    assert class_imbalance_check.validate(X, y_multiclass_balanced) == {"warnings": [], "errors": [], "actions": []}
+
+
+@pytest.mark.parametrize("input_type", ["pd", "ww"])
+@pytest.mark.parametrize("min_samples", [1, 20, 50, 100, 500])
+def test_class_imbalance_severe(min_samples, input_type):
+    X = pd.DataFrame()
+    # 0 will be < 10% of the data, but there will be 50 samples of it
+    y_values_binary = pd.Series([0, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1, 1] * 50)
+    y_values_multiclass = pd.Series([0, 1, 1, 1, 1, 1, 1, 2, 2, 2, 2, 2, 2] * 50)
+    if input_type == "ww":
+        X = ww.DataTable(X)
+        y_values_binary = ww.DataColumn(y_values_binary)
+        y_values_multiclass = ww.DataColumn(y_values_multiclass)
+
+    class_imbalance_check = ClassImbalanceDataCheck(min_samples=min_samples, num_cv_folds=1)
+    warnings = [DataCheckWarning(message="The following labels fall below 10% of the target: [0]",
+                                 data_check_name=class_imbalance_data_check_name,
+                                 message_code=DataCheckMessageCode.CLASS_IMBALANCE_BELOW_THRESHOLD,
+                                 details={"target_values": [0]}).to_dict()]
+    if min_samples > 50:
+        warnings.append(DataCheckWarning(message=f"The following labels in the target have severe class imbalance because they fall under 10% of the target and have less than {min_samples} samples: [0]",
+                                         data_check_name=class_imbalance_data_check_name,
+                                         message_code=DataCheckMessageCode.CLASS_IMBALANCE_SEVERE,
+                                         details={"target_values": [0]}).to_dict())
+    assert class_imbalance_check.validate(X, y_values_binary) == {
+        "warnings": warnings,
+        "errors": [],
+        "actions": []
+    }
+
+    assert class_imbalance_check.validate(X, y_values_multiclass) == {
+        "warnings": warnings,
+        "errors": [],
+        "actions": []
+    }
