@@ -65,7 +65,8 @@ def test_target_leakage_data_check_warnings():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": "d"}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
 
@@ -74,7 +75,7 @@ def test_target_leakage_data_check_empty(data_type, make_data_type):
     X = make_data_type(data_type, pd.DataFrame())
     y = make_data_type(data_type, pd.Series())
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.8, method='mutual')
-    assert leakage_check.validate(X, y) == {"warnings": [], "errors": []}
+    assert leakage_check.validate(X, y) == {"warnings": [], "errors": [], "actions": []}
 
 
 def test_target_leakage_data_check_input_formats():
@@ -105,7 +106,8 @@ def test_target_leakage_data_check_input_formats():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": "d"}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
     # test X as ww.DataTable, y as ww.DataColumn
     assert leakage_check.validate(ww.DataTable(X), ww.DataColumn(y)) == expected_messages
@@ -131,7 +133,8 @@ def test_target_leakage_data_check_input_formats():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": 3}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
 
@@ -145,7 +148,8 @@ def test_target_leakage_none():
 
     expected_messages = {
         "warnings": [],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     assert leakage_check.validate(X, y) == expected_messages
@@ -180,7 +184,8 @@ def test_target_leakage_types():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": "d"}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     assert leakage_check.validate(X, y) == expected_messages
@@ -190,7 +195,7 @@ def test_target_leakage_multi():
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.8)
 
     # test empty pd.DataFrame, empty pd.Series
-    assert leakage_check.validate(pd.DataFrame(), pd.Series()) == {"warnings": [], "errors": []}
+    assert leakage_check.validate(pd.DataFrame(), pd.Series()) == {"warnings": [], "errors": [], "actions": []}
 
     y = pd.Series([1, 0, 2, 1, 2, 0])
     X = pd.DataFrame()
@@ -213,7 +218,8 @@ def test_target_leakage_multi():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": "c"}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     # test X as ww.DataTable, y as ww.DataColumn
@@ -227,15 +233,15 @@ def test_target_leakage_regression():
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.8)
 
     # test empty pd.DataFrame, empty pd.Series
-    assert leakage_check.validate(pd.DataFrame(), pd.Series()) == {"warnings": [], "errors": []}
+    assert leakage_check.validate(pd.DataFrame(), pd.Series()) == {"warnings": [], "errors": [], "actions": []}
 
-    y = pd.Series([0.4, 0.1, 2.3, 4.3, 2.2, 1.8, 3.7, 3.6, 2.4, 0.9, 3.1, 2.8, 4.1, 1.6, 1.2])
+    y = pd.Series([0.4, 0.4, 2.3, 4.3, 2.2, 1.8, 3.7, 3.6, 2.4, 0.9, 3.1, 2.8, 4.1, 1.6, 1.2])
     X = pd.DataFrame()
     X["a"] = y * 3
     X["b"] = y - 1
     X["c"] = y / 10
     X["d"] = [0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0, 0]
-    X["e"] = ["a", "b", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o"]
+    X["e"] = ["a", "a", "c", "d", "e", "f", "g", "h", "i", "j", "k", "l", "m", "n", "o"]
 
     expected_messages = {
         "warnings": [DataCheckWarning(message="Column 'a' is 80.0% or more correlated with the target",
@@ -254,7 +260,8 @@ def test_target_leakage_regression():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": "e"}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     # test X as ww.DataTable, y as ww.DataColumn
@@ -292,14 +299,16 @@ def test_target_leakage_data_check_warnings_pearson():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": "d"}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     y = ["a", "b", "a", "a"]
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.5, method='pearson')
     assert leakage_check.validate(X, y) == {
         "warnings": [],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
 
@@ -307,7 +316,7 @@ def test_target_leakage_data_check_input_formats_pearson():
     leakage_check = TargetLeakageDataCheck(pct_corr_threshold=0.8, method='pearson')
 
     # test empty pd.DataFrame, empty pd.Series
-    assert leakage_check.validate(pd.DataFrame(), pd.Series()) == {"warnings": [], "errors": []}
+    assert leakage_check.validate(pd.DataFrame(), pd.Series()) == {"warnings": [], "errors": [], "actions": []}
 
     y = pd.Series([1, 0, 1, 1])
     X = pd.DataFrame()
@@ -335,7 +344,8 @@ def test_target_leakage_data_check_input_formats_pearson():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": "d"}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     # test X as np.array
@@ -356,7 +366,8 @@ def test_target_leakage_data_check_input_formats_pearson():
                                       data_check_name=target_leakage_data_check_name,
                                       message_code=DataCheckMessageCode.TARGET_LEAKAGE,
                                       details={"column": 3}).to_dict()],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     # test X as ww.DataTable, y as ww.DataColumn
@@ -376,7 +387,8 @@ def test_target_leakage_none_pearson():
 
     expected_messages = {
         "warnings": [],
-        "errors": []
+        "errors": [],
+        "actions": []
     }
 
     assert leakage_check.validate(X, y) == expected_messages
