@@ -1,5 +1,4 @@
 import json
-import warnings
 from unittest.mock import MagicMock, patch
 
 import numpy as np
@@ -11,11 +10,13 @@ from evalml.exceptions import PipelineScoreError
 from evalml.model_understanding.prediction_explanations.explainers import (
     abs_error,
     cross_entropy,
-    explain_prediction,
     explain_predictions,
     explain_predictions_best_worst
 )
 from evalml.pipelines import (
+    BinaryClassificationPipeline,
+    MulticlassClassificationPipeline,
+    RegressionPipeline,
     TimeSeriesBinaryClassificationPipeline,
     TimeSeriesRegressionPipeline
 )
@@ -28,213 +29,6 @@ def compare_two_tables(table_1, table_2):
         assert row.strip().split() == row_answer.strip().split()
 
 
-test_features = [[1], np.ones((15, 1)), pd.DataFrame({"a": [1, 2, 3], "b": [1, 2, 3]}).iloc[0],
-                 pd.DataFrame({"a": [1, 2, 3], "b": [4, 5, 6]}), pd.DataFrame()]
-
-
-explain_prediction_answer = """Feature Name Feature Value Contribution to Prediction
-                               =========================================================
-                                 d           40.00          +++++
-                                 b           20.00          -----""".splitlines()
-
-explain_prediction_regression_dict_answer = {
-    "explanations": [{
-        "feature_names": ["d", "b"],
-        "feature_values": [40, 20],
-        "qualitative_explanation": ["+++++", "-----"],
-        "quantitative_explanation": [None, None],
-        "class_name": None
-    }]
-}
-
-explain_predictions_regression_df_answer = pd.DataFrame({'feature_names': ['d', 'b'],
-                                                         'feature_values': [40, 20],
-                                                         'qualitative_explanation': ['+++++', '-----'],
-                                                         "quantitative_explanation": [None, None]})
-
-explain_prediction_binary_dict_answer = {
-    "explanations": [{
-        "feature_names": ["d", "b"],
-        "feature_values": [40, 20],
-        "qualitative_explanation": ["+++++", "-----"],
-        "quantitative_explanation": [None, None],
-        "class_name": "class_1"
-    }]
-}
-
-explain_prediction_binary_df_answer = pd.DataFrame({
-    "feature_names": ["d", "b"],
-    "feature_values": [40, 20],
-    "qualitative_explanation": ["+++++", "-----"],
-    "quantitative_explanation": [None, None],
-    "class_name": ["class_1", "class_1"]
-})
-
-explain_prediction_multiclass_answer = """Class: class_0
-
-        Feature Name Feature Value Contribution to Prediction
-       =========================================================
-            a           10.00               +++++
-            c           30.00                ---
-
-
-        Class: class_1
-
-        Feature Name Feature Value Contribution to Prediction
-       =========================================================
-            a           10.00               +++
-            b           20.00               ++
-
-
-        Class: class_2
-
-        Feature Name Feature Value Contribution to Prediction
-        =========================================================
-            c          30.00           ---
-            d          40.00           ---
-            """.splitlines()
-
-explain_prediction_multiclass_dict_answer = {
-    "explanations": [
-        {"feature_names": ["a", "c"],
-         "feature_values": [10, 30],
-         "qualitative_explanation": ["+++++", "---"],
-         "quantitative_explanation": [None, None],
-         "class_name": "class_0"},
-        {"feature_names": ["a", "b"],
-         "feature_values": [10, 20],
-         "qualitative_explanation": ["+++", "++"],
-         "quantitative_explanation": [None, None],
-         "class_name": "class_1"},
-        {"feature_names": ["c", "d"],
-         "feature_values": [30, 40],
-         "qualitative_explanation": ["---", "---"],
-         "quantitative_explanation": [None, None],
-         "class_name": "class_2"},
-    ]
-}
-
-explain_prediction_multiclass_df_answer = pd.DataFrame({
-    "feature_names": ["a", "c", "a", "b", "c", "d"],
-    "feature_values": [10, 30, 10, 20, 30, 40],
-    "qualitative_explanation": ["+++++", "---", "+++", "++", "---", "---"],
-    "quantitative_explanation": [None, None, None, None, None, None],
-    "class_name": ['class_0', 'class_0', 'class_1', 'class_1', 'class_2', 'class_2']
-})
-
-
-@pytest.mark.parametrize("problem_type, output_format, shap_values, normalized_shap_values, answer",
-                         [(ProblemTypes.REGRESSION,
-                           "text",
-                           {"a": [1], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           {"a": [0.5], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           explain_prediction_answer),
-                          (ProblemTypes.REGRESSION,
-                           "dict",
-                           {"a": [1], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           {"a": [0.5], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           explain_prediction_regression_dict_answer
-                           ),
-                          (ProblemTypes.REGRESSION,
-                           "dataframe",
-                           {"a": [1], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           {"a": [0.5], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           explain_predictions_regression_df_answer
-                           ),
-                          (ProblemTypes.TIME_SERIES_REGRESSION,
-                           "text",
-                           {"a": [1], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           {"a": [0.5], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           explain_prediction_answer),
-                          (ProblemTypes.TIME_SERIES_REGRESSION,
-                           "dict",
-                           {"a": [1], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           {"a": [0.5], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           explain_prediction_regression_dict_answer
-                           ),
-                          (ProblemTypes.TIME_SERIES_REGRESSION,
-                           "dataframe",
-                           {"a": [1], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           {"a": [0.5], "b": [-2.1], "c": [-0.25], "d": [2.3]},
-                           explain_predictions_regression_df_answer
-                           ),
-                          (ProblemTypes.BINARY,
-                           "text",
-                           [{}, {"a": [0.5], "b": [-0.89], "c": [0.33], "d": [0.89]}],
-                           [{}, {"a": [0.5], "b": [-0.89], "c": [-0.25], "d": [0.89]}],
-                           explain_prediction_answer),
-                          (ProblemTypes.BINARY,
-                           "dict",
-                           [{}, {"a": [0.5], "b": [-0.89], "c": [0.33], "d": [0.89]}],
-                           [{}, {"a": [0.5], "b": [-0.89], "c": [-0.25], "d": [0.89]}],
-                           explain_prediction_binary_dict_answer),
-                          (ProblemTypes.BINARY,
-                           "dataframe",
-                           [{}, {"a": [0.5], "b": [-0.89], "c": [0.33], "d": [0.89]}],
-                           [{}, {"a": [0.5], "b": [-0.89], "c": [-0.25], "d": [0.89]}],
-                           explain_prediction_binary_df_answer),
-                          (ProblemTypes.MULTICLASS,
-                           "text",
-                           [{}, {}, {}],
-                           [{"a": [1.1], "b": [0.09], "c": [-0.53], "d": [-0.06]},
-                            {"a": [0.53], "b": [0.24], "c": [-0.15], "d": [-0.22]},
-                            {"a": [0.03], "b": [0.02], "c": [-0.42], "d": [-0.47]}],
-                           explain_prediction_multiclass_answer),
-                          (ProblemTypes.MULTICLASS,
-                           "dict",
-                           [{}, {}, {}],
-                           [{"a": [1.1], "b": [0.09], "c": [-0.53], "d": [-0.06]},
-                            {"a": [0.53], "b": [0.24], "c": [-0.15], "d": [-0.22]},
-                            {"a": [0.03], "b": [0.02], "c": [-0.42], "d": [-0.47]}],
-                           explain_prediction_multiclass_dict_answer),
-                          (ProblemTypes.MULTICLASS,
-                           "dataframe",
-                           [{}, {}, {}],
-                           [{"a": [1.1], "b": [0.09], "c": [-0.53], "d": [-0.06]},
-                            {"a": [0.53], "b": [0.24], "c": [-0.15], "d": [-0.22]},
-                            {"a": [0.03], "b": [0.02], "c": [-0.42], "d": [-0.47]}],
-                           explain_prediction_multiclass_df_answer)
-                          ])
-@pytest.mark.parametrize("input_type", ["pd", "ww"])
-@patch("evalml.model_understanding.prediction_explanations._user_interface._compute_shap_values")
-@patch("evalml.model_understanding.prediction_explanations._user_interface._normalize_shap_values")
-def test_explain_prediction(mock_normalize_shap_values,
-                            mock_compute_shap_values,
-                            problem_type, output_format, shap_values, normalized_shap_values, answer,
-                            input_type):
-    mock_compute_shap_values.return_value = shap_values
-    mock_normalize_shap_values.return_value = normalized_shap_values
-    pipeline = MagicMock()
-    pipeline.problem_type = problem_type
-    pipeline.classes_ = ["class_0", "class_1", "class_2"]
-
-    # By the time we call transform, we are looking at only one row of the input data.
-    pipeline.compute_estimator_features.return_value = ww.DataTable(pd.DataFrame({"a": [10], "b": [20], "c": [30], "d": [40]}))
-    features = pd.DataFrame({"a": [1], "b": [2]})
-    if input_type == "ww":
-        features = ww.DataTable(features)
-
-    with warnings.catch_warnings(record=True) as warn:
-        warnings.simplefilter("always")
-        table = explain_prediction(pipeline, features, y=None, output_format=output_format, index_to_explain=0,
-                                   top_k_features=2)
-        assert str(warn[0].message).startswith("The explain_prediction function will be deleted in the next release")
-    if isinstance(table, str):
-        compare_two_tables(table.splitlines(), answer)
-    elif isinstance(table, pd.DataFrame):
-        pd.testing.assert_frame_equal(table, answer)
-    else:
-        assert table == answer
-
-
-def test_explain_prediction_errors():
-    with pytest.raises(ValueError, match="Explained indices should be between"):
-        explain_prediction(MagicMock(), pd.DataFrame({"a": [0, 1, 2, 3, 4]}), y=None, index_to_explain=5)
-
-    with pytest.raises(ValueError, match="Explained indices should be between"):
-        explain_prediction(MagicMock(), pd.DataFrame({"a": [0, 1, 2, 3, 4]}), y=None, index_to_explain=-1)
-
-
 def test_error_metrics():
 
     np.testing.assert_array_equal(abs_error(pd.Series([1, 2, 3]), pd.Series([4, 1, 0])), np.array([3, 1, 3]))
@@ -285,8 +79,6 @@ def test_output_format_checked():
     input_features, y_true = pd.DataFrame(data=[range(15)]), pd.Series(range(15))
     with pytest.raises(ValueError, match="Parameter output_format must be either text, dict, or dataframe. Received bar"):
         explain_predictions(pipeline=MagicMock(), input_features=input_features, y=None, indices_to_explain=0, output_format="bar")
-    with pytest.raises(ValueError, match="Parameter output_format must be either text, dict, or dataframe. Received xml"):
-        explain_prediction(pipeline=MagicMock(), input_features=input_features, y=None, index_to_explain=0, output_format="xml")
 
     input_features, y_true = pd.DataFrame(data=range(15)), pd.Series(range(15))
     with pytest.raises(ValueError, match="Parameter output_format must be either text, dict, or dataframe. Received foo"):
@@ -820,3 +612,213 @@ def test_json_serialization(problem_type, X_y_regression, linear_regression_pipe
 
     report = explain_predictions(pipeline, pd.DataFrame(X), y=y, output_format="dict", indices_to_explain=[0])
     assert json.loads(json.dumps(report)) == report
+
+
+def transform_y_for_problem_type(problem_type, y):
+
+    if problem_type == ProblemTypes.REGRESSION:
+        y = y.astype("int")
+    elif problem_type == ProblemTypes.MULTICLASS:
+        y = pd.Series(y).astype("str")
+        y[:20] = "2"
+    return y
+
+
+EXPECTED_DATETIME_FEATURES = {'datetime_hour', 'datetime_year', 'datetime_month', 'datetime_day_of_week'}
+
+EXPECTED_DATETIME_FEATURES_OHE = {'datetime_hour', 'datetime_year', 'datetime_month_3',
+                                  'datetime_day_of_week_0', 'datetime_day_of_week_1', 'datetime_day_of_week_2', 'datetime_day_of_week_3',
+                                  'datetime_day_of_week_4', 'datetime_day_of_week_5', 'datetime_day_of_week_6',
+                                  'datetime_month_0', 'datetime_month_1', 'datetime_month_2', 'datetime_month_4',
+                                  'datetime_month_5', 'datetime_month_6', 'datetime_month_7'}
+
+EXPECTED_CURRENCY_FEATURES = {'currency_XDR', 'currency_MUR', 'currency_NIS', 'currency_CNY', 'currency_TZS',
+                              'currency_LAK', 'currency_MOP', 'currency_IMP', 'currency_QAR', 'currency_EGP'}
+
+EXPECTED_PROVIDER_FEATURES_OHE = {'provider_JCB 16 digit', 'provider_Discover', 'provider_American Express',
+                                  'provider_JCB 15 digit', 'provider_Maestro', 'provider_VISA 19 digit',
+                                  'provider_VISA 13 digit', 'provider_Mastercard', 'provider_VISA 16 digit',
+                                  'provider_Diners Club / Carte Blanche'}
+
+EXPECTED_PROVIDER_FEATURES_TEXT = {'DIVERSITY_SCORE(provider)', 'LSA(provider)[0]', 'LSA(provider)[1]',
+                                   'MEAN_CHARACTERS_PER_WORD(provider)', 'POLARITY_SCORE(provider)'}
+
+pipeline_test_cases = [(BinaryClassificationPipeline, "Random Forest Classifier"),
+                       (RegressionPipeline, "Random Forest Regressor"),
+                       (MulticlassClassificationPipeline, "Random Forest Classifier")]
+
+
+@pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
+def test_categories_aggregated_linear_pipeline(pipeline_class, estimator, fraud_100):
+
+    X, y = fraud_100
+    y = y.to_series()
+
+    class LinearPipelineBinary(pipeline_class):
+        component_graph = ["Select Columns Transformer", "One Hot Encoder",
+                           "DateTime Featurization Component", estimator]
+
+    pipeline = LinearPipelineBinary({"Select Columns Transformer": {'columns': ['amount', 'provider', "currency"]},
+                                     estimator: {"n_jobs": 1}})
+
+    y = transform_y_for_problem_type(pipeline.problem_type, y)
+
+    pipeline.fit(X, y)
+
+    report = explain_predictions(pipeline, X, y, indices_to_explain=[0], output_format="dict")
+    for explanation in report["explanations"][0]['explanations']:
+        assert set(explanation['feature_names']) == {"amount", "provider", "currency"}
+        assert set(explanation['feature_values']) == {"CUC", "Mastercard", 24900}
+        assert explanation['drill_down'].keys() == {"currency", "provider"}
+        assert set(explanation['drill_down']['currency']['feature_names']) == EXPECTED_CURRENCY_FEATURES
+        assert set(explanation['drill_down']['provider']['feature_names']) == EXPECTED_PROVIDER_FEATURES_OHE
+
+
+@pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
+def test_categories_aggregated_text(pipeline_class, estimator, fraud_100):
+
+    X, y = fraud_100
+    y = y.to_series()
+    X = X.set_types(logical_types={'provider': 'NaturalLanguage'})
+
+    class LinearPipelineText(pipeline_class):
+        component_graph = ["Select Columns Transformer", "One Hot Encoder",
+                           "Text Featurization Component", "DateTime Featurization Component",
+                           estimator]
+
+    pipeline = LinearPipelineText({"Select Columns Transformer": {'columns': ['amount', 'provider', "currency", 'datetime']},
+                                   estimator: {"n_jobs": 1}})
+
+    y = transform_y_for_problem_type(pipeline.problem_type, y)
+
+    pipeline.fit(X, y)
+
+    report = explain_predictions(pipeline, X, y, indices_to_explain=[0], top_k_features=4, output_format="dict")
+    for explanation in report["explanations"][0]['explanations']:
+        assert set(explanation['feature_names']) == {"amount", "provider", "currency", "datetime"}
+        assert set(explanation['feature_values']) == {"CUC", "Mastercard", 24900, pd.Timestamp('2019-01-01 00:12:26')}
+        assert explanation['drill_down'].keys() == {"currency", "provider", "datetime"}
+        assert set(explanation['drill_down']['currency']['feature_names']) == EXPECTED_CURRENCY_FEATURES
+        assert set(explanation['drill_down']['provider']['feature_names']) == EXPECTED_PROVIDER_FEATURES_TEXT
+        assert set(explanation['drill_down']['datetime']['feature_names']) == EXPECTED_DATETIME_FEATURES
+
+
+@pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
+def test_categories_aggregated_date_ohe(pipeline_class, estimator, fraud_100):
+
+    X, y = fraud_100
+    y = y.to_series()
+
+    class LinearPipelineEncodeDatesAsCategory(pipeline_class):
+        component_graph = ["Select Columns Transformer", "DateTime Featurization Component",
+                           "One Hot Encoder", estimator]
+
+    pipeline = LinearPipelineEncodeDatesAsCategory({"Select Columns Transformer": {'columns': ['datetime', 'amount', 'provider', "currency"]},
+                                                    'DateTime Featurization Component': {"encode_as_categories": True},
+                                                    estimator: {"n_jobs": 1}})
+
+    y = transform_y_for_problem_type(pipeline.problem_type, y)
+
+    pipeline.fit(X, y)
+    report = explain_predictions(pipeline, X, y, indices_to_explain=[0], output_format="dict", top_k_features=7)
+
+    for explanation in report["explanations"][0]['explanations']:
+        assert set(explanation['feature_names']) == {"amount", "provider", "currency", "datetime"}
+        assert set(explanation['feature_values']) == {pd.Timestamp('2019-01-01 00:12:26'), 'Mastercard', 'CUC', 24900}
+        assert explanation['drill_down'].keys() == {"currency", "provider", "datetime"}
+        assert set(explanation['drill_down']['datetime']['feature_names']) == EXPECTED_DATETIME_FEATURES_OHE
+        assert set(explanation['drill_down']['currency']['feature_names']) == EXPECTED_CURRENCY_FEATURES
+        assert set(explanation['drill_down']['provider']['feature_names']) == EXPECTED_PROVIDER_FEATURES_OHE
+
+
+@pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
+def test_categories_aggregated_pca_dag(pipeline_class, estimator, fraud_100):
+
+    X, y = fraud_100
+    y = y.to_series()
+
+    class PcaDagPipeline(pipeline_class):
+        component_graph = {
+            'SelectNumeric': ["Select Columns Transformer"],
+            'SelectCategorical': ["Select Columns Transformer"],
+            'SelectDate': ["Select Columns Transformer"],
+            'OHE': ['One Hot Encoder', 'SelectCategorical'],
+            'DT': ['DateTime Featurization Component', "SelectDate"],
+            'PCA': ['PCA Transformer', 'SelectNumeric'],
+            'Estimator': [estimator, 'PCA', 'DT', 'OHE'],
+        }
+
+    pipeline = PcaDagPipeline({'SelectNumeric': {'columns': ['card_id', 'store_id', 'amount', 'lat', 'lng']},
+                               'SelectCategorical': {'columns': ['currency', 'provider']},
+                               'SelectDate': {'columns': ['datetime']},
+                               'PCA': {"n_components": 2},
+                               'Estimator': {"n_jobs": 1}})
+    y = transform_y_for_problem_type(pipeline.problem_type, y)
+
+    pipeline.fit(X, y)
+    report = explain_predictions(pipeline, X, y, indices_to_explain=[0], output_format="dict", top_k_features=7)
+
+    for explanation in report["explanations"][0]["explanations"]:
+        assert set(explanation['feature_names']) == {"component_0", "component_1", "provider", "currency", "datetime"}
+        assert all([f in explanation['feature_values'] for f in [pd.Timestamp('2019-01-01 00:12:26'), 'Mastercard', 'CUC']])
+        assert explanation['drill_down'].keys() == {"currency", "provider", "datetime"}
+        assert set(explanation['drill_down']['currency']['feature_names']) == EXPECTED_CURRENCY_FEATURES
+        assert set(explanation['drill_down']['provider']['feature_names']) == EXPECTED_PROVIDER_FEATURES_OHE
+        assert set(explanation['drill_down']['datetime']['feature_names']) == EXPECTED_DATETIME_FEATURES
+
+
+@pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
+def test_categories_aggregated_but_not_those_that_are_dropped(pipeline_class, estimator, fraud_100):
+
+    X, y = fraud_100
+    y = y.to_series()
+
+    class LinearPipelineDropDates(pipeline_class):
+        component_graph = ["Select Columns Transformer", "One Hot Encoder",
+                           "DateTime Featurization Component", 'Drop Columns Transformer', estimator]
+
+    pipeline = LinearPipelineDropDates({"Select Columns Transformer": {'columns': ['amount', 'provider', "currency",
+                                                                                   "datetime"]},
+                                        "Drop Columns Transformer": {"columns": list(EXPECTED_DATETIME_FEATURES)},
+                                        estimator: {"n_jobs": 1}})
+
+    y = transform_y_for_problem_type(pipeline.problem_type, y)
+
+    pipeline.fit(X, y)
+
+    report = explain_predictions(pipeline, X, y, indices_to_explain=[0], output_format="dict")
+    for explanation in report["explanations"][0]['explanations']:
+        assert set(explanation['feature_names']) == {"amount", "provider", "currency"}
+        assert set(explanation['feature_values']) == {"CUC", "Mastercard", 24900}
+        assert explanation['drill_down'].keys() == {"currency", "provider"}
+        assert set(explanation['drill_down']['currency']['feature_names']) == EXPECTED_CURRENCY_FEATURES
+        assert set(explanation['drill_down']['provider']['feature_names']) == EXPECTED_PROVIDER_FEATURES_OHE
+
+
+@pytest.mark.parametrize("pipeline_class,estimator", pipeline_test_cases)
+def test_categories_aggregated_when_some_are_dropped(pipeline_class, estimator, fraud_100):
+
+    X, y = fraud_100
+    y = y.to_series()
+
+    class LinearPipelineDropDates(pipeline_class):
+        component_graph = ["Select Columns Transformer", "One Hot Encoder",
+                           "DateTime Featurization Component", 'Drop Columns Transformer', estimator]
+
+    pipeline = LinearPipelineDropDates({"Select Columns Transformer": {'columns': ['amount', 'provider', "currency",
+                                                                                   "datetime"]},
+                                        "Drop Columns Transformer": {"columns": ["datetime_month", "datetime_hour"]},
+                                        estimator: {"n_jobs": 1}})
+
+    y = transform_y_for_problem_type(pipeline.problem_type, y)
+
+    pipeline.fit(X, y)
+
+    report = explain_predictions(pipeline, X, y, indices_to_explain=[0], output_format="dict", top_k_features=4)
+    for explanation in report["explanations"][0]['explanations']:
+        assert set(explanation['feature_names']) == {"amount", "provider", "currency", "datetime"}
+        assert set(explanation['feature_values']) == {"CUC", "Mastercard", 24900, pd.Timestamp('2019-01-01 00:12:26')}
+        assert explanation['drill_down'].keys() == {"currency", "provider", "datetime"}
+        assert set(explanation['drill_down']['currency']['feature_names']) == EXPECTED_CURRENCY_FEATURES
+        assert set(explanation['drill_down']['provider']['feature_names']) == EXPECTED_PROVIDER_FEATURES_OHE
+        assert set(explanation['drill_down']['datetime']['feature_names']) == {"datetime_year", "datetime_day_of_week"}
