@@ -1,10 +1,12 @@
+import warnings
+
 import numpy as np
 import pytest
 
 from evalml.tuners import NoParamsException, RandomSearchTuner
 from evalml.tuners.tuner import Tuner
 
-random_state = 0
+random_seed = 0
 
 
 def test_random_search_tuner_inheritance():
@@ -12,7 +14,7 @@ def test_random_search_tuner_inheritance():
 
 
 def test_random_search_tuner_unique_values(dummy_pipeline_hyperparameters):
-    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters, random_state=random_state)
+    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters, random_seed=random_seed)
     generated_parameters = []
     for i in range(3):
         params = tuner.propose()
@@ -24,7 +26,7 @@ def test_random_search_tuner_unique_values(dummy_pipeline_hyperparameters):
 
 
 def test_random_search_tuner_no_params(dummy_pipeline_hyperparameters_small):
-    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters_small, random_state=random_state, with_replacement=False)
+    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters_small, random_seed=random_seed, with_replacement=False)
     error_text = "Cannot create a unique set of unexplored parameters. Try expanding the search space."
     with pytest.raises(NoParamsException, match=error_text):
         for i in range(10):
@@ -32,7 +34,7 @@ def test_random_search_tuner_no_params(dummy_pipeline_hyperparameters_small):
 
 
 def test_random_search_tuner_with_replacement(dummy_pipeline_hyperparameters):
-    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters, random_state=random_state, with_replacement=True)
+    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters, random_seed=random_seed, with_replacement=True)
     for i in range(10):
         proposal = tuner.propose()
         assert isinstance(proposal, dict)
@@ -42,7 +44,7 @@ def test_random_search_tuner_with_replacement(dummy_pipeline_hyperparameters):
 
 def test_random_search_tuner_basic(dummy_pipeline_hyperparameters,
                                    dummy_pipeline_hyperparameters_unicode):
-    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters, random_state=random_state)
+    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters, random_seed=random_seed)
     proposed_params = tuner.propose()
     assert proposed_params == {
         'Mock Classifier': {
@@ -54,7 +56,7 @@ def test_random_search_tuner_basic(dummy_pipeline_hyperparameters,
     }
     tuner.add(proposed_params, 0.5)
 
-    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters_unicode, random_state=random_state)
+    tuner = RandomSearchTuner(dummy_pipeline_hyperparameters_unicode, random_seed=random_seed)
     proposed_params = tuner.propose()
     assert proposed_params == {
         'Mock Classifier': {
@@ -68,15 +70,15 @@ def test_random_search_tuner_basic(dummy_pipeline_hyperparameters,
 
 
 def test_random_search_tuner_space_types():
-    tuner = RandomSearchTuner({'Mock Classifier': {'param a': (0, 10)}}, random_state=random_state)
+    tuner = RandomSearchTuner({'Mock Classifier': {'param a': (0, 10)}}, random_seed=random_seed)
     proposed_params = tuner.propose()
     assert proposed_params == {'Mock Classifier': {'param a': 5}}
 
-    tuner = RandomSearchTuner({'Mock Classifier': {'param a': (0, 10.0)}}, random_state=random_state)
+    tuner = RandomSearchTuner({'Mock Classifier': {'param a': (0, 10.0)}}, random_seed=random_seed)
     proposed_params = tuner.propose()
     assert proposed_params == {'Mock Classifier': {'param a': 5.488135039273248}}
 
-    tuner = RandomSearchTuner({'Mock Classifier': {'param a': 10.0}}, random_state=random_state)
+    tuner = RandomSearchTuner({'Mock Classifier': {'param a': 10.0}}, random_seed=random_seed)
     proposed_params = tuner.propose()
     assert proposed_params == {'Mock Classifier': {}}
 
@@ -84,6 +86,13 @@ def test_random_search_tuner_space_types():
 def test_random_search_tuner_invalid_space():
     bound_error_text = "has to be less than the upper bound"
     with pytest.raises(ValueError, match=bound_error_text):
-        RandomSearchTuner({'Mock Classifier': {'param a': (1, 0)}}, random_state=random_state)
+        RandomSearchTuner({'Mock Classifier': {'param a': (1, 0)}}, random_seed=random_seed)
     with pytest.raises(ValueError, match=bound_error_text):
-        RandomSearchTuner({'Mock Classifier': {'param a': (0, 0)}}, random_state=random_state)
+        RandomSearchTuner({'Mock Classifier': {'param a': (0, 0)}}, random_seed=random_seed)
+
+
+def test_random_search_tuner_raises_deprecated_random_state_warning():
+    with warnings.catch_warnings(record=True) as warn:
+        warnings.simplefilter("always")
+        RandomSearchTuner({'Mock Classifier': {'param a': (0, 2)}}, random_state=random_seed)
+        assert str(warn[0].message).startswith("Argument 'random_state' has been deprecated in favor of 'random_seed'")
